From a1c0a73f00203628eff0aa4cea0919182b589e28 Mon Sep 17 00:00:00 2001
From: Mark Dilger <mark.dilger@enterprisedb.com>
Date: Tue, 31 Aug 2021 16:44:29 -0700
Subject: [PATCH v6 06/19] Adding role pg_manage_replication_settings

This new role can SET and ALTER SYSTEM SET any GUC variable which
controls replication behavior or resource usage.
---
 doc/src/sgml/user-manag.sgml                  |    9 +-
 src/backend/utils/misc/guc.c                  |   48 +-
 src/include/catalog/pg_authid.dat             |    5 +
 src/include/utils/guc.h                       |    1 +
 .../regress/expected/replication_settings.out | 1711 +++++++++++++++++
 src/test/regress/parallel_schedule            |    2 +-
 src/test/regress/sql/replication_settings.sql | 1051 ++++++++++
 7 files changed, 2802 insertions(+), 25 deletions(-)
 create mode 100644 src/test/regress/expected/replication_settings.out
 create mode 100644 src/test/regress/sql/replication_settings.sql

diff --git a/doc/src/sgml/user-manag.sgml b/doc/src/sgml/user-manag.sgml
index e898dba880..a982fb37b0 100644
--- a/doc/src/sgml/user-manag.sgml
+++ b/doc/src/sgml/user-manag.sgml
@@ -598,6 +598,10 @@ DROP ROLE doomed_role;
        <entry>pg_manage_logging_settings</entry>
        <entry>Allow changing settings which control logging behavior.</entry>
       </row>
+      <row>
+       <entry>pg_manage_replication_settings</entry>
+       <entry>Allow changing settings which control replication behavior.</entry>
+      </row>
      </tbody>
     </tgroup>
    </table>
@@ -644,8 +648,9 @@ DROP ROLE doomed_role;
   <para>
   The <literal>pg_manage_host_resource_settings</literal>,
   <literal>pg_manage_vacuum_settings</literal>,
-  <literal>pg_manage_autovacuum_settings</literal> and
-  <literal>pg_manage_logging_settings</literal> roles are intended to allow
+  <literal>pg_manage_autovacuum_settings</literal>,
+  <literal>pg_manage_logging_settings</literal> and
+  <literal>pg_manage_replication_settings</literal> roles are intended to allow
   administrators to have trusted, but non-superuser, roles to configure the
   server.
   </para>
diff --git a/src/backend/utils/misc/guc.c b/src/backend/utils/misc/guc.c
index f64f05c74c..2f23a73147 100644
--- a/src/backend/utils/misc/guc.c
+++ b/src/backend/utils/misc/guc.c
@@ -1227,7 +1227,7 @@ static struct config_bool ConfigureNamesBool[] =
 		{"track_commit_timestamp", PGC_POSTMASTER, REPLICATION_SENDING,
 			gettext_noop("Collects transaction commit time."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&track_commit_timestamp,
 		false,
@@ -1996,7 +1996,7 @@ static struct config_bool ConfigureNamesBool[] =
 		{"hot_standby", PGC_POSTMASTER, REPLICATION_STANDBY,
 			gettext_noop("Allows connections and queries during recovery."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&EnableHotStandby,
 		true,
@@ -2007,7 +2007,7 @@ static struct config_bool ConfigureNamesBool[] =
 		{"hot_standby_feedback", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Allows feedback from a hot standby to the primary that will avoid query conflicts."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&hot_standby_feedback,
 		false,
@@ -2219,7 +2219,7 @@ static struct config_bool ConfigureNamesBool[] =
 		{"wal_receiver_create_temp_slot", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets whether a WAL receiver should create a temporary replication slot if no permanent slot is configured."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&wal_receiver_create_temp_slot,
 		false,
@@ -2359,7 +2359,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"max_standby_archive_delay", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the maximum delay before canceling queries when a hot standby server is processing archived WAL data."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&max_standby_archive_delay,
@@ -2371,7 +2371,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"max_standby_streaming_delay", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the maximum delay before canceling queries when a hot standby server is processing streamed WAL data."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&max_standby_streaming_delay,
@@ -2383,7 +2383,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"recovery_min_apply_delay", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the minimum delay for applying changes during recovery."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&recovery_min_apply_delay,
@@ -2395,7 +2395,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"wal_receiver_status_interval", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the maximum interval between WAL receiver status reports to the sending server."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_S
 		},
 		&wal_receiver_status_interval,
@@ -2407,7 +2407,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"wal_receiver_timeout", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the maximum wait time to receive data from the sending server."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&wal_receiver_timeout,
@@ -2805,7 +2805,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"vacuum_defer_cleanup_age", PGC_SIGHUP, REPLICATION_PRIMARY,
 			gettext_noop("Number of transactions by which VACUUM and HOT cleanup should be deferred, if any."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&vacuum_defer_cleanup_age,
 		0, 0, 1000000,			/* see ComputeXidHorizons */
@@ -2914,7 +2914,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"wal_keep_size", PGC_SIGHUP, REPLICATION_SENDING,
 			gettext_noop("Sets the size of WAL files held for standby servers."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MB
 		},
 		&wal_keep_size_mb,
@@ -3039,7 +3039,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"max_wal_senders", PGC_POSTMASTER, REPLICATION_SENDING,
 			gettext_noop("Sets the maximum number of simultaneously running WAL sender processes."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&max_wal_senders,
 		10, 0, MAX_BACKENDS,
@@ -3051,7 +3051,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"max_replication_slots", PGC_POSTMASTER, REPLICATION_SENDING,
 			gettext_noop("Sets the maximum number of simultaneously defined replication slots."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&max_replication_slots,
 		10, 0, MAX_BACKENDS /* XXX? */ ,
@@ -3064,7 +3064,7 @@ static struct config_int ConfigureNamesInt[] =
 			gettext_noop("Replication slots will be marked as failed, and segments released "
 						 "for deletion or recycling, if this much space is occupied by WAL "
 						 "on disk."),
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MB
 		},
 		&max_slot_wal_keep_size_mb,
@@ -3076,7 +3076,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"wal_sender_timeout", PGC_USERSET, REPLICATION_SENDING,
 			gettext_noop("Sets the maximum time to wait for WAL replication."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&wal_sender_timeout,
@@ -3291,7 +3291,7 @@ static struct config_int ConfigureNamesInt[] =
 			REPLICATION_SUBSCRIBERS,
 			gettext_noop("Maximum number of logical replication worker processes."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&max_logical_replication_workers,
 		4, 0, MAX_BACKENDS,
@@ -3304,7 +3304,7 @@ static struct config_int ConfigureNamesInt[] =
 			REPLICATION_SUBSCRIBERS,
 			gettext_noop("Maximum number of table synchronization workers per subscription."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&max_sync_workers_per_subscription,
 		2, 0, MAX_BACKENDS,
@@ -3412,7 +3412,7 @@ static struct config_int ConfigureNamesInt[] =
 			gettext_noop("Sets the time to wait before retrying to retrieve WAL "
 						 "after a failed attempt."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&wal_retrieve_retry_interval,
@@ -4192,7 +4192,7 @@ static struct config_string ConfigureNamesString[] =
 		{"promote_trigger_file", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Specifies a file name whose presence ends recovery in the standby."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&PromoteTriggerFile,
 		"",
@@ -4203,7 +4203,7 @@ static struct config_string ConfigureNamesString[] =
 		{"primary_conninfo", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the connection string to be used to connect to the sending server."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&PrimaryConnInfo,
 		"",
@@ -4214,7 +4214,7 @@ static struct config_string ConfigureNamesString[] =
 		{"primary_slot_name", PGC_SIGHUP, REPLICATION_STANDBY,
 			gettext_noop("Sets the name of the replication slot to use on the sending server."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_REPLICATION_SETTINGS
 		},
 		&PrimarySlotName,
 		"",
@@ -4780,7 +4780,7 @@ static struct config_string ConfigureNamesString[] =
 		{"synchronous_standby_names", PGC_SIGHUP, REPLICATION_PRIMARY,
 			gettext_noop("Number of synchronous standbys and list of names of potential synchronous ones."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_REPLICATION_SETTINGS,
 			GUC_LIST_INPUT
 		},
 		&SyncRepStandbyNames,
@@ -7624,6 +7624,10 @@ role_has_privileges(Oid roleid, int privileges)
 		! has_privs_of_role(roleid, ROLE_PG_WRITE_SERVER_FILES))
 		return false;
 
+	if ((privileges & GUC_MANAGE_REPLICATION_SETTINGS) &&
+		! has_privs_of_role(roleid, ROLE_PG_MANAGE_REPLICATION_SETTINGS))
+		return false;
+
 	return true;
 }
 
diff --git a/src/include/catalog/pg_authid.dat b/src/include/catalog/pg_authid.dat
index 41d119f7b2..b36c81bf95 100644
--- a/src/include/catalog/pg_authid.dat
+++ b/src/include/catalog/pg_authid.dat
@@ -99,5 +99,10 @@
   rolcreaterole => 'f', rolcreatedb => 'f', rolcanlogin => 'f',
   rolreplication => 'f', rolbypassrls => 't', rolconnlimit => '-1',
   rolpassword => '_null_', rolvaliduntil => '_null_' },
+{ oid => '9283', oid_symbol => 'ROLE_PG_MANAGE_REPLICATION_SETTINGS',
+  rolname => 'pg_manage_replication_settings', rolsuper => 'f', rolinherit => 't',
+  rolcreaterole => 'f', rolcreatedb => 'f', rolcanlogin => 'f',
+  rolreplication => 'f', rolbypassrls => 't', rolconnlimit => '-1',
+  rolpassword => '_null_', rolvaliduntil => '_null_' },
 
 ]
diff --git a/src/include/utils/guc.h b/src/include/utils/guc.h
index c80c7d8ec5..fc31feb74d 100644
--- a/src/include/utils/guc.h
+++ b/src/include/utils/guc.h
@@ -206,6 +206,7 @@ typedef enum
 #define GUC_MANAGE_AUTOVACUUM_SETTINGS		0x0004
 #define GUC_MANAGE_LOGGING_SETTINGS			0x0008
 #define GUC_WRITE_SERVER_FILES				0x0010
+#define GUC_MANAGE_REPLICATION_SETTINGS		0x0020
 
 /*
  * bit values in "flags" of a GUC variable
diff --git a/src/test/regress/expected/replication_settings.out b/src/test/regress/expected/replication_settings.out
new file mode 100644
index 0000000000..03038ea537
--- /dev/null
+++ b/src/test/regress/expected/replication_settings.out
@@ -0,0 +1,1711 @@
+-- Non-superuser with privileges to configure replication settings
+CREATE ROLE regress_replication_admin NOSUPERUSER;
+GRANT pg_manage_replication_settings TO regress_replication_admin;
+-- Perform all operations as user 'regress_replication_admin' --
+SET SESSION AUTHORIZATION regress_replication_admin;
+-- PGC_BACKEND / DEVELOPER_OPTIONS
+ALTER SYSTEM SET ignore_system_indexes = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_system_indexes"
+ALTER SYSTEM RESET ignore_system_indexes;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_system_indexes"
+ALTER SYSTEM SET post_auth_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "post_auth_delay"
+ALTER SYSTEM RESET post_auth_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "post_auth_delay"
+-- PGC_INTERNAL / PRESET_OPTIONS
+-- PGC_INTERNAL / UNGROUPED
+-- PGC_POSTMASTER / AUTOVACUUM
+ALTER SYSTEM SET autovacuum_freeze_max_age = 1000050000;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_freeze_max_age"
+ALTER SYSTEM RESET autovacuum_freeze_max_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_freeze_max_age"
+ALTER SYSTEM SET autovacuum_max_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_max_workers"
+ALTER SYSTEM RESET autovacuum_max_workers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_max_workers"
+ALTER SYSTEM SET autovacuum_multixact_freeze_max_age = 1000005000;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_multixact_freeze_max_age"
+ALTER SYSTEM RESET autovacuum_multixact_freeze_max_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_multixact_freeze_max_age"
+-- PGC_POSTMASTER / CLIENT_CONN_PRELOAD
+ALTER SYSTEM SET jit_provider = 'llvmjit';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_provider"
+ALTER SYSTEM RESET jit_provider;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_provider"
+ALTER SYSTEM SET shared_preload_libraries = 'iconv, pcre';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_preload_libraries"
+ALTER SYSTEM RESET shared_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_preload_libraries"
+-- PGC_POSTMASTER / CONN_AUTH_SETTINGS
+ALTER SYSTEM SET bonjour = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour"
+ALTER SYSTEM RESET bonjour;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour"
+ALTER SYSTEM SET bonjour_name = 'BonneNuit';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour_name"
+ALTER SYSTEM RESET bonjour_name;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour_name"
+ALTER SYSTEM SET listen_addresses = 'localhost';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "listen_addresses"
+ALTER SYSTEM RESET listen_addresses;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "listen_addresses"
+ALTER SYSTEM SET max_connections = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_connections"
+ALTER SYSTEM RESET max_connections;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_connections"
+ALTER SYSTEM SET port = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "port"
+ALTER SYSTEM RESET port;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "port"
+ALTER SYSTEM SET superuser_reserved_connections = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "superuser_reserved_connections"
+ALTER SYSTEM RESET superuser_reserved_connections;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "superuser_reserved_connections"
+ALTER SYSTEM SET unix_socket_directories = '/tmp';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_directories"
+ALTER SYSTEM RESET unix_socket_directories;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_directories"
+ALTER SYSTEM SET unix_socket_group = 'tenant';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_group"
+ALTER SYSTEM RESET unix_socket_group;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_group"
+ALTER SYSTEM SET unix_socket_permissions = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_permissions"
+ALTER SYSTEM RESET unix_socket_permissions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_permissions"
+-- PGC_POSTMASTER / DEVELOPER_OPTIONS
+ALTER SYSTEM SET ignore_invalid_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_invalid_pages"
+ALTER SYSTEM RESET ignore_invalid_pages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_invalid_pages"
+-- PGC_POSTMASTER / ERROR_HANDLING_OPTIONS
+ALTER SYSTEM SET data_sync_retry = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "data_sync_retry"
+ALTER SYSTEM RESET data_sync_retry;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "data_sync_retry"
+-- PGC_POSTMASTER / FILE_LOCATIONS
+ALTER SYSTEM SET external_pid_file = '/var/postgres/master.pid';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "external_pid_file"
+ALTER SYSTEM RESET external_pid_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "external_pid_file"
+-- PGC_POSTMASTER / LOCK_MANAGEMENT
+ALTER SYSTEM SET max_locks_per_transaction = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_locks_per_transaction"
+ALTER SYSTEM RESET max_locks_per_transaction;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_locks_per_transaction"
+ALTER SYSTEM SET max_pred_locks_per_transaction = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_transaction"
+ALTER SYSTEM RESET max_pred_locks_per_transaction;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_transaction"
+-- PGC_POSTMASTER / LOGGING_WHERE
+ALTER SYSTEM SET event_source = 'PostgreSQL';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "event_source"
+ALTER SYSTEM RESET event_source;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "event_source"
+ALTER SYSTEM SET logging_collector = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logging_collector"
+ALTER SYSTEM RESET logging_collector;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logging_collector"
+-- PGC_POSTMASTER / PROCESS_TITLE
+ALTER SYSTEM SET cluster_name = 'BonCluster';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cluster_name"
+ALTER SYSTEM RESET cluster_name;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cluster_name"
+-- PGC_POSTMASTER / REPLICATION_SENDING
+ALTER SYSTEM SET max_replication_slots = 50;  -- ok
+ALTER SYSTEM RESET max_replication_slots;  -- ok
+ALTER SYSTEM SET max_wal_senders = 50;  -- ok
+ALTER SYSTEM RESET max_wal_senders;  -- ok
+ALTER SYSTEM SET track_commit_timestamp = OFF;  -- ok
+ALTER SYSTEM RESET track_commit_timestamp;  -- ok
+-- PGC_POSTMASTER / REPLICATION_STANDBY
+ALTER SYSTEM SET hot_standby = OFF;  -- ok
+ALTER SYSTEM RESET hot_standby;  -- ok
+-- PGC_POSTMASTER / REPLICATION_SUBSCRIBERS
+ALTER SYSTEM SET max_logical_replication_workers = 50;  -- ok
+ALTER SYSTEM RESET max_logical_replication_workers;  -- ok
+-- PGC_POSTMASTER / RESOURCES_ASYNCHRONOUS
+ALTER SYSTEM SET max_worker_processes = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_worker_processes"
+ALTER SYSTEM RESET max_worker_processes;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_worker_processes"
+ALTER SYSTEM SET old_snapshot_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "old_snapshot_threshold"
+ALTER SYSTEM RESET old_snapshot_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "old_snapshot_threshold"
+-- PGC_POSTMASTER / RESOURCES_KERNEL
+ALTER SYSTEM SET max_files_per_process = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_files_per_process"
+ALTER SYSTEM RESET max_files_per_process;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_files_per_process"
+-- PGC_POSTMASTER / RESOURCES_MEM
+ALTER SYSTEM SET dynamic_shared_memory_type = 'posix';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_shared_memory_type"
+ALTER SYSTEM RESET dynamic_shared_memory_type;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_shared_memory_type"
+ALTER SYSTEM SET huge_pages = 'try';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "huge_pages"
+ALTER SYSTEM RESET huge_pages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "huge_pages"
+ALTER SYSTEM SET max_prepared_transactions = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_prepared_transactions"
+ALTER SYSTEM RESET max_prepared_transactions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_prepared_transactions"
+ALTER SYSTEM SET min_dynamic_shared_memory = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_dynamic_shared_memory"
+ALTER SYSTEM RESET min_dynamic_shared_memory;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_dynamic_shared_memory"
+ALTER SYSTEM SET shared_buffers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_buffers"
+ALTER SYSTEM RESET shared_buffers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_buffers"
+ALTER SYSTEM SET shared_memory_type = 'mmap';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_memory_type"
+ALTER SYSTEM RESET shared_memory_type;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_memory_type"
+-- PGC_POSTMASTER / STATS_COLLECTOR
+ALTER SYSTEM SET track_activity_query_size = 524338;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activity_query_size"
+ALTER SYSTEM RESET track_activity_query_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activity_query_size"
+-- PGC_POSTMASTER / WAL_ARCHIVING
+ALTER SYSTEM SET archive_mode = 'off';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_mode"
+ALTER SYSTEM RESET archive_mode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_mode"
+-- PGC_POSTMASTER / WAL_RECOVERY_TARGET
+ALTER SYSTEM SET recovery_target_action = 'pause';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_action"
+ALTER SYSTEM RESET recovery_target_action;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_action"
+ALTER SYSTEM SET recovery_target_inclusive = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_inclusive"
+ALTER SYSTEM RESET recovery_target_inclusive;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_inclusive"
+ALTER SYSTEM SET recovery_target_lsn = '16/B374D848';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_lsn"
+ALTER SYSTEM RESET recovery_target_lsn;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_lsn"
+ALTER SYSTEM SET recovery_target_name = 'BonPoint';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_name"
+ALTER SYSTEM RESET recovery_target_name;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_name"
+ALTER SYSTEM SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_time"
+ALTER SYSTEM RESET recovery_target_time;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_time"
+ALTER SYSTEM SET recovery_target_timeline = 'latest';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_timeline"
+ALTER SYSTEM RESET recovery_target_timeline;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_timeline"
+ALTER SYSTEM SET recovery_target_xid = '12345678';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_xid"
+ALTER SYSTEM RESET recovery_target_xid;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_xid"
+-- PGC_POSTMASTER / WAL_SETTINGS
+ALTER SYSTEM SET wal_buffers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_buffers"
+ALTER SYSTEM RESET wal_buffers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_buffers"
+ALTER SYSTEM SET wal_level = 'replica';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_level"
+ALTER SYSTEM RESET wal_level;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_level"
+ALTER SYSTEM SET wal_log_hints = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_log_hints"
+ALTER SYSTEM RESET wal_log_hints;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_log_hints"
+-- PGC_SIGHUP / AUTOVACUUM
+ALTER SYSTEM SET autovacuum = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum"
+ALTER SYSTEM RESET autovacuum;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum"
+ALTER SYSTEM SET autovacuum_analyze_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_analyze_scale_factor"
+ALTER SYSTEM RESET autovacuum_analyze_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_analyze_scale_factor"
+ALTER SYSTEM SET autovacuum_analyze_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_analyze_threshold"
+ALTER SYSTEM RESET autovacuum_analyze_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_analyze_threshold"
+ALTER SYSTEM SET autovacuum_naptime = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_naptime"
+ALTER SYSTEM RESET autovacuum_naptime;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_naptime"
+ALTER SYSTEM SET autovacuum_vacuum_cost_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_cost_delay"
+ALTER SYSTEM RESET autovacuum_vacuum_cost_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_cost_delay"
+ALTER SYSTEM SET autovacuum_vacuum_cost_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_cost_limit"
+ALTER SYSTEM RESET autovacuum_vacuum_cost_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_cost_limit"
+ALTER SYSTEM SET autovacuum_vacuum_insert_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_insert_scale_factor"
+ALTER SYSTEM RESET autovacuum_vacuum_insert_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_insert_scale_factor"
+ALTER SYSTEM SET autovacuum_vacuum_insert_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_insert_threshold"
+ALTER SYSTEM RESET autovacuum_vacuum_insert_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_insert_threshold"
+ALTER SYSTEM SET autovacuum_vacuum_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_scale_factor"
+ALTER SYSTEM RESET autovacuum_vacuum_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_scale_factor"
+ALTER SYSTEM SET autovacuum_vacuum_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_threshold"
+ALTER SYSTEM RESET autovacuum_vacuum_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_vacuum_threshold"
+-- PGC_SIGHUP / CONN_AUTH_AUTH
+ALTER SYSTEM SET authentication_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "authentication_timeout"
+ALTER SYSTEM RESET authentication_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "authentication_timeout"
+ALTER SYSTEM SET db_user_namespace = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "db_user_namespace"
+ALTER SYSTEM RESET db_user_namespace;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "db_user_namespace"
+ALTER SYSTEM SET krb_caseins_users = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_caseins_users"
+ALTER SYSTEM RESET krb_caseins_users;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_caseins_users"
+ALTER SYSTEM SET krb_server_keyfile = 'krb/server.key';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_server_keyfile"
+ALTER SYSTEM RESET krb_server_keyfile;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_server_keyfile"
+-- PGC_SIGHUP / CONN_AUTH_SSL
+ALTER SYSTEM SET ssl_ca_file = 'ca/server.ca';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ca_file"
+ALTER SYSTEM RESET ssl_ca_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ca_file"
+ALTER SYSTEM SET ssl_cert_file = 'crt/server.crt';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_cert_file"
+ALTER SYSTEM RESET ssl_cert_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_cert_file"
+ALTER SYSTEM SET ssl_ciphers = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ciphers"
+ALTER SYSTEM RESET ssl_ciphers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ciphers"
+ALTER SYSTEM SET ssl_crl_dir = 'crl/';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_dir"
+ALTER SYSTEM RESET ssl_crl_dir;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_dir"
+ALTER SYSTEM SET ssl_crl_file = 'crl/server.crl';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_file"
+ALTER SYSTEM RESET ssl_crl_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_file"
+ALTER SYSTEM SET ssl_dh_params_file = 'ssl/params';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_dh_params_file"
+ALTER SYSTEM RESET ssl_dh_params_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_dh_params_file"
+ALTER SYSTEM SET ssl_ecdh_curve = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ecdh_curve"
+ALTER SYSTEM RESET ssl_ecdh_curve;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ecdh_curve"
+ALTER SYSTEM SET ssl_key_file = 'crl/server.key';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_key_file"
+ALTER SYSTEM RESET ssl_key_file;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_key_file"
+ALTER SYSTEM SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_min_protocol_version"
+ALTER SYSTEM RESET ssl_min_protocol_version;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_min_protocol_version"
+ALTER SYSTEM SET ssl_passphrase_command = '/bin/passphrase';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command"
+ALTER SYSTEM RESET ssl_passphrase_command;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command"
+ALTER SYSTEM SET ssl_passphrase_command_supports_reload = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command_supports_reload"
+ALTER SYSTEM RESET ssl_passphrase_command_supports_reload;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command_supports_reload"
+ALTER SYSTEM SET ssl_prefer_server_ciphers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_prefer_server_ciphers"
+ALTER SYSTEM RESET ssl_prefer_server_ciphers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_prefer_server_ciphers"
+-- PGC_SIGHUP / DEVELOPER_OPTIONS
+ALTER SYSTEM SET pre_auth_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "pre_auth_delay"
+ALTER SYSTEM RESET pre_auth_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "pre_auth_delay"
+ALTER SYSTEM SET remove_temp_files_after_crash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "remove_temp_files_after_crash"
+ALTER SYSTEM RESET remove_temp_files_after_crash;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "remove_temp_files_after_crash"
+ALTER SYSTEM SET trace_recovery_messages = 'log';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_recovery_messages"
+ALTER SYSTEM RESET trace_recovery_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_recovery_messages"
+-- PGC_SIGHUP / ERROR_HANDLING_OPTIONS
+ALTER SYSTEM SET recovery_init_sync_method = 'fsync';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_init_sync_method"
+ALTER SYSTEM RESET recovery_init_sync_method;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_init_sync_method"
+ALTER SYSTEM SET restart_after_crash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restart_after_crash"
+ALTER SYSTEM RESET restart_after_crash;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restart_after_crash"
+-- PGC_SIGHUP / LOCK_MANAGEMENT
+ALTER SYSTEM SET max_pred_locks_per_page = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_page"
+ALTER SYSTEM RESET max_pred_locks_per_page;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_page"
+ALTER SYSTEM SET max_pred_locks_per_relation = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_relation"
+ALTER SYSTEM RESET max_pred_locks_per_relation;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_relation"
+-- PGC_SIGHUP / LOGGING_WHAT
+ALTER SYSTEM SET log_autovacuum_min_duration = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_autovacuum_min_duration"
+ALTER SYSTEM RESET log_autovacuum_min_duration;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_autovacuum_min_duration"
+ALTER SYSTEM SET log_checkpoints = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_checkpoints"
+ALTER SYSTEM RESET log_checkpoints;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_checkpoints"
+ALTER SYSTEM SET log_hostname = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_hostname"
+ALTER SYSTEM RESET log_hostname;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_hostname"
+ALTER SYSTEM SET log_line_prefix = '%m [%p] ';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_line_prefix"
+ALTER SYSTEM RESET log_line_prefix;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_line_prefix"
+ALTER SYSTEM SET log_recovery_conflict_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_recovery_conflict_waits"
+ALTER SYSTEM RESET log_recovery_conflict_waits;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_recovery_conflict_waits"
+ALTER SYSTEM SET log_timezone = 'Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_timezone"
+ALTER SYSTEM RESET log_timezone;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_timezone"
+-- PGC_SIGHUP / LOGGING_WHERE
+ALTER SYSTEM SET log_directory = 'log';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_directory"
+ALTER SYSTEM RESET log_directory;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_directory"
+ALTER SYSTEM SET log_file_mode = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_file_mode"
+ALTER SYSTEM RESET log_file_mode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_file_mode"
+ALTER SYSTEM SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_filename"
+ALTER SYSTEM RESET log_filename;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_filename"
+ALTER SYSTEM SET log_rotation_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_age"
+ALTER SYSTEM RESET log_rotation_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_age"
+ALTER SYSTEM SET log_rotation_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_size"
+ALTER SYSTEM RESET log_rotation_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_size"
+ALTER SYSTEM SET log_truncate_on_rotation = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_truncate_on_rotation"
+ALTER SYSTEM RESET log_truncate_on_rotation;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_truncate_on_rotation"
+ALTER SYSTEM SET syslog_ident = 'postgres';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_ident"
+ALTER SYSTEM RESET syslog_ident;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_ident"
+ALTER SYSTEM SET syslog_sequence_numbers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_sequence_numbers"
+ALTER SYSTEM RESET syslog_sequence_numbers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_sequence_numbers"
+ALTER SYSTEM SET syslog_split_messages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_split_messages"
+ALTER SYSTEM RESET syslog_split_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_split_messages"
+-- PGC_SIGHUP / REPLICATION_PRIMARY
+ALTER SYSTEM SET synchronous_standby_names = 'fee, fi, fo, fum';  -- ok
+ALTER SYSTEM RESET synchronous_standby_names;  -- ok
+ALTER SYSTEM SET vacuum_defer_cleanup_age = 50;  -- ok
+ALTER SYSTEM RESET vacuum_defer_cleanup_age;  -- ok
+-- PGC_SIGHUP / REPLICATION_SENDING
+ALTER SYSTEM SET max_slot_wal_keep_size = 50;  -- ok
+ALTER SYSTEM RESET max_slot_wal_keep_size;  -- ok
+ALTER SYSTEM SET wal_keep_size = 50;  -- ok
+ALTER SYSTEM RESET wal_keep_size;  -- ok
+-- PGC_SIGHUP / REPLICATION_STANDBY
+ALTER SYSTEM SET hot_standby_feedback = OFF;  -- ok
+ALTER SYSTEM RESET hot_standby_feedback;  -- ok
+ALTER SYSTEM SET max_standby_archive_delay = 50;  -- ok
+ALTER SYSTEM RESET max_standby_archive_delay;  -- ok
+ALTER SYSTEM SET max_standby_streaming_delay = 50;  -- ok
+ALTER SYSTEM RESET max_standby_streaming_delay;  -- ok
+ALTER SYSTEM SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- ok
+ALTER SYSTEM RESET primary_conninfo;  -- ok
+ALTER SYSTEM SET primary_slot_name = 'bonne_fente';  -- ok
+ALTER SYSTEM RESET primary_slot_name;  -- ok
+ALTER SYSTEM SET promote_trigger_file = 'promote.trigger';  -- ok
+ALTER SYSTEM RESET promote_trigger_file;  -- ok
+ALTER SYSTEM SET recovery_min_apply_delay = 50;  -- ok
+ALTER SYSTEM RESET recovery_min_apply_delay;  -- ok
+ALTER SYSTEM SET wal_receiver_create_temp_slot = OFF;  -- ok
+ALTER SYSTEM RESET wal_receiver_create_temp_slot;  -- ok
+ALTER SYSTEM SET wal_receiver_status_interval = 50;  -- ok
+ALTER SYSTEM RESET wal_receiver_status_interval;  -- ok
+ALTER SYSTEM SET wal_receiver_timeout = 50;  -- ok
+ALTER SYSTEM RESET wal_receiver_timeout;  -- ok
+ALTER SYSTEM SET wal_retrieve_retry_interval = 50;  -- ok
+ALTER SYSTEM RESET wal_retrieve_retry_interval;  -- ok
+-- PGC_SIGHUP / REPLICATION_SUBSCRIBERS
+ALTER SYSTEM SET max_sync_workers_per_subscription = 50;  -- ok
+ALTER SYSTEM RESET max_sync_workers_per_subscription;  -- ok
+-- PGC_SIGHUP / RESOURCES_BGWRITER
+ALTER SYSTEM SET bgwriter_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_delay"
+ALTER SYSTEM RESET bgwriter_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_delay"
+ALTER SYSTEM SET bgwriter_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_flush_after"
+ALTER SYSTEM RESET bgwriter_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_flush_after"
+ALTER SYSTEM SET bgwriter_lru_maxpages = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_maxpages"
+ALTER SYSTEM RESET bgwriter_lru_maxpages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_maxpages"
+ALTER SYSTEM SET bgwriter_lru_multiplier = 5;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_multiplier"
+ALTER SYSTEM RESET bgwriter_lru_multiplier;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_multiplier"
+-- PGC_SIGHUP / RESOURCES_MEM
+ALTER SYSTEM SET autovacuum_work_mem = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_work_mem"
+ALTER SYSTEM RESET autovacuum_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_work_mem"
+-- PGC_SIGHUP / STATS_COLLECTOR
+ALTER SYSTEM SET stats_temp_directory = 'pg_stat_tmp';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "stats_temp_directory"
+ALTER SYSTEM RESET stats_temp_directory;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "stats_temp_directory"
+-- PGC_SIGHUP / WAL_ARCHIVE_RECOVERY
+ALTER SYSTEM SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_cleanup_command"
+ALTER SYSTEM RESET archive_cleanup_command;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_cleanup_command"
+ALTER SYSTEM SET recovery_end_command = '/bin/recover my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_end_command"
+ALTER SYSTEM RESET recovery_end_command;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_end_command"
+ALTER SYSTEM SET restore_command = '/bin/restore my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restore_command"
+ALTER SYSTEM RESET restore_command;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restore_command"
+-- PGC_SIGHUP / WAL_ARCHIVING
+ALTER SYSTEM SET archive_command = '/bin/archive my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_command"
+ALTER SYSTEM RESET archive_command;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_command"
+ALTER SYSTEM SET archive_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_timeout"
+ALTER SYSTEM RESET archive_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_timeout"
+-- PGC_SIGHUP / WAL_CHECKPOINTS
+ALTER SYSTEM SET checkpoint_warning = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_warning"
+ALTER SYSTEM RESET checkpoint_warning;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_warning"
+ALTER SYSTEM SET checkpoint_completion_target = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_completion_target"
+ALTER SYSTEM RESET checkpoint_completion_target;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_completion_target"
+ALTER SYSTEM SET checkpoint_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_flush_after"
+ALTER SYSTEM RESET checkpoint_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_flush_after"
+ALTER SYSTEM SET checkpoint_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_timeout"
+ALTER SYSTEM RESET checkpoint_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_timeout"
+ALTER SYSTEM SET max_wal_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_size"
+ALTER SYSTEM RESET max_wal_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_size"
+ALTER SYSTEM SET min_wal_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_wal_size"
+ALTER SYSTEM RESET min_wal_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_wal_size"
+-- PGC_SIGHUP / WAL_SETTINGS
+ALTER SYSTEM SET fsync = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "fsync"
+ALTER SYSTEM RESET fsync;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "fsync"
+ALTER SYSTEM SET full_page_writes = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "full_page_writes"
+ALTER SYSTEM RESET full_page_writes;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "full_page_writes"
+ALTER SYSTEM SET wal_sync_method = 'open_datasync';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sync_method"
+ALTER SYSTEM RESET wal_sync_method;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sync_method"
+ALTER SYSTEM SET wal_writer_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_delay"
+ALTER SYSTEM RESET wal_writer_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_delay"
+ALTER SYSTEM SET wal_writer_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_flush_after"
+ALTER SYSTEM RESET wal_writer_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_flush_after"
+-- PGC_SUSET / CLIENT_CONN_LOCALE
+SET lc_messages = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+RESET lc_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+ALTER SYSTEM SET lc_messages = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+ALTER SYSTEM RESET lc_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+-- PGC_SUSET / CLIENT_CONN_OTHER
+SET dynamic_library_path = '$libdir';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+RESET dynamic_library_path;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+ALTER SYSTEM SET dynamic_library_path = '$libdir';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+ALTER SYSTEM RESET dynamic_library_path;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+-- PGC_SUSET / CLIENT_CONN_PRELOAD
+SET session_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+RESET session_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+ALTER SYSTEM SET session_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+ALTER SYSTEM RESET session_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+-- PGC_SUSET / CLIENT_CONN_STATEMENT
+SET session_replication_role = 'origin';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+RESET session_replication_role;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+ALTER SYSTEM SET session_replication_role = 'origin';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+ALTER SYSTEM RESET session_replication_role;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+-- PGC_SUSET / COMPAT_OPTIONS_PREVIOUS
+SET lo_compat_privileges = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+RESET lo_compat_privileges;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+ALTER SYSTEM SET lo_compat_privileges = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+ALTER SYSTEM RESET lo_compat_privileges;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+-- PGC_SUSET / DEVELOPER_OPTIONS
+SET allow_system_table_mods = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+RESET allow_system_table_mods;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+ALTER SYSTEM SET allow_system_table_mods = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+ALTER SYSTEM RESET allow_system_table_mods;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+RESET backtrace_functions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+ALTER SYSTEM SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+ALTER SYSTEM RESET backtrace_functions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+SET debug_discard_caches = 2;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+RESET debug_discard_caches;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+ALTER SYSTEM SET debug_discard_caches = 2;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+ALTER SYSTEM RESET debug_discard_caches;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+SET ignore_checksum_failure = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+RESET ignore_checksum_failure;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+ALTER SYSTEM SET ignore_checksum_failure = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+ALTER SYSTEM RESET ignore_checksum_failure;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+SET jit_dump_bitcode = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+RESET jit_dump_bitcode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+ALTER SYSTEM SET jit_dump_bitcode = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+ALTER SYSTEM RESET jit_dump_bitcode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+RESET wal_consistency_checking;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+ALTER SYSTEM SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+ALTER SYSTEM RESET wal_consistency_checking;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+SET zero_damaged_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+RESET zero_damaged_pages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+ALTER SYSTEM SET zero_damaged_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+ALTER SYSTEM RESET zero_damaged_pages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+-- PGC_SUSET / LOCK_MANAGEMENT
+SET deadlock_timeout = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+RESET deadlock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+ALTER SYSTEM SET deadlock_timeout = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+ALTER SYSTEM RESET deadlock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+-- PGC_SUSET / LOGGING_WHAT
+SET log_duration = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+RESET log_duration;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+ALTER SYSTEM SET log_duration = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+ALTER SYSTEM RESET log_duration;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+SET log_error_verbosity = 'default';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+RESET log_error_verbosity;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+ALTER SYSTEM SET log_error_verbosity = 'default';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+ALTER SYSTEM RESET log_error_verbosity;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+SET log_lock_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+RESET log_lock_waits;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+ALTER SYSTEM SET log_lock_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+ALTER SYSTEM RESET log_lock_waits;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+SET log_parameter_max_length = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+RESET log_parameter_max_length;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+ALTER SYSTEM SET log_parameter_max_length = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+ALTER SYSTEM RESET log_parameter_max_length;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+SET log_replication_commands = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+RESET log_replication_commands;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+ALTER SYSTEM SET log_replication_commands = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+ALTER SYSTEM RESET log_replication_commands;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+SET log_statement = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+RESET log_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+ALTER SYSTEM SET log_statement = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+ALTER SYSTEM RESET log_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+SET log_temp_files = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+RESET log_temp_files;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+ALTER SYSTEM SET log_temp_files = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+ALTER SYSTEM RESET log_temp_files;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+-- PGC_SUSET / LOGGING_WHEN
+SET log_min_duration_sample = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+RESET log_min_duration_sample;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+ALTER SYSTEM SET log_min_duration_sample = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+ALTER SYSTEM RESET log_min_duration_sample;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+SET log_min_duration_statement = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+RESET log_min_duration_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+ALTER SYSTEM SET log_min_duration_statement = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+ALTER SYSTEM RESET log_min_duration_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+SET log_min_error_statement = 'error';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+RESET log_min_error_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+ALTER SYSTEM SET log_min_error_statement = 'error';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+ALTER SYSTEM RESET log_min_error_statement;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+SET log_min_messages = 'warning';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+RESET log_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+ALTER SYSTEM SET log_min_messages = 'warning';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+ALTER SYSTEM RESET log_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+SET log_statement_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+RESET log_statement_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+ALTER SYSTEM SET log_statement_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+ALTER SYSTEM RESET log_statement_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+SET log_transaction_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+RESET log_transaction_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+ALTER SYSTEM SET log_transaction_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+ALTER SYSTEM RESET log_transaction_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+-- PGC_SUSET / PROCESS_TITLE
+SET update_process_title = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+RESET update_process_title;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+ALTER SYSTEM SET update_process_title = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+ALTER SYSTEM RESET update_process_title;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+-- PGC_SUSET / RESOURCES_DISK
+SET temp_file_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+RESET temp_file_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+ALTER SYSTEM SET temp_file_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+ALTER SYSTEM RESET temp_file_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+-- PGC_SUSET / RESOURCES_MEM
+SET max_stack_depth = 3890;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+RESET max_stack_depth;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+ALTER SYSTEM SET max_stack_depth = 3890;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+ALTER SYSTEM RESET max_stack_depth;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+-- PGC_SUSET / STATS_COLLECTOR
+SET track_activities = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+RESET track_activities;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+ALTER SYSTEM SET track_activities = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+ALTER SYSTEM RESET track_activities;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+SET track_counts = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+RESET track_counts;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+ALTER SYSTEM SET track_counts = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+ALTER SYSTEM RESET track_counts;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+SET track_functions = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+RESET track_functions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+ALTER SYSTEM SET track_functions = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+ALTER SYSTEM RESET track_functions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+SET track_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+RESET track_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+ALTER SYSTEM SET track_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+ALTER SYSTEM RESET track_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+SET track_wal_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+RESET track_wal_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+ALTER SYSTEM SET track_wal_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+ALTER SYSTEM RESET track_wal_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+-- PGC_SUSET / STATS_MONITORING
+SET log_executor_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+RESET log_executor_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+ALTER SYSTEM SET log_executor_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+ALTER SYSTEM RESET log_executor_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+SET log_parser_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+RESET log_parser_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+ALTER SYSTEM SET log_parser_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+ALTER SYSTEM RESET log_parser_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+SET log_planner_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+RESET log_planner_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+ALTER SYSTEM SET log_planner_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+ALTER SYSTEM RESET log_planner_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+SET log_statement_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+RESET log_statement_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+ALTER SYSTEM SET log_statement_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+ALTER SYSTEM RESET log_statement_stats;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+SET compute_query_id = 'auto';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+RESET compute_query_id;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+ALTER SYSTEM SET compute_query_id = 'auto';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+ALTER SYSTEM RESET compute_query_id;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+-- PGC_SUSET / WAL_SETTINGS
+SET commit_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+RESET commit_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+ALTER SYSTEM SET commit_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+ALTER SYSTEM RESET commit_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+SET wal_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+RESET wal_compression;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+ALTER SYSTEM SET wal_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+ALTER SYSTEM RESET wal_compression;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+SET wal_init_zero = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+RESET wal_init_zero;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+ALTER SYSTEM SET wal_init_zero = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+ALTER SYSTEM RESET wal_init_zero;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+SET wal_recycle = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+RESET wal_recycle;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+ALTER SYSTEM SET wal_recycle = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+ALTER SYSTEM RESET wal_recycle;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+-- PGC_SU_BACKEND / DEVELOPER_OPTIONS
+ALTER SYSTEM SET jit_debugging_support = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_debugging_support"
+ALTER SYSTEM RESET jit_debugging_support;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_debugging_support"
+ALTER SYSTEM SET jit_profiling_support = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_profiling_support"
+ALTER SYSTEM RESET jit_profiling_support;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_profiling_support"
+-- PGC_SU_BACKEND / LOGGING_WHAT
+ALTER SYSTEM SET log_connections = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_connections"
+ALTER SYSTEM RESET log_connections;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_connections"
+ALTER SYSTEM SET log_disconnections = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_disconnections"
+ALTER SYSTEM RESET log_disconnections;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_disconnections"
+-- PGC_USERSET / CLIENT_CONN_LOCALE
+SET DateStyle = 'ISO, MDY';  -- ok
+RESET DateStyle;  -- ok
+ALTER SYSTEM SET DateStyle = 'ISO, MDY';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "datestyle"
+ALTER SYSTEM RESET DateStyle;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "datestyle"
+SET IntervalStyle = 'postgres';  -- ok
+RESET IntervalStyle;  -- ok
+ALTER SYSTEM SET IntervalStyle = 'postgres';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "intervalstyle"
+ALTER SYSTEM RESET IntervalStyle;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "intervalstyle"
+SET TimeZone = 'Europe/Helsinki';  -- ok
+RESET TimeZone;  -- ok
+ALTER SYSTEM SET TimeZone = 'Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone"
+ALTER SYSTEM RESET TimeZone;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone"
+SET client_encoding = 'UTF8';  -- ok
+RESET client_encoding;  -- ok
+ALTER SYSTEM SET client_encoding = 'UTF8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_encoding"
+ALTER SYSTEM RESET client_encoding;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_encoding"
+SET default_text_search_config = 'pg_catalog.english';  -- ok
+RESET default_text_search_config;  -- ok
+ALTER SYSTEM SET default_text_search_config = 'pg_catalog.english';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_text_search_config"
+ALTER SYSTEM RESET default_text_search_config;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_text_search_config"
+SET extra_float_digits = -6;  -- ok
+RESET extra_float_digits;  -- ok
+ALTER SYSTEM SET extra_float_digits = -6;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "extra_float_digits"
+ALTER SYSTEM RESET extra_float_digits;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "extra_float_digits"
+SET lc_monetary = 'en_US.UTF-8';  -- ok
+RESET lc_monetary;  -- ok
+ALTER SYSTEM SET lc_monetary = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_monetary"
+ALTER SYSTEM RESET lc_monetary;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_monetary"
+SET lc_numeric = 'en_US.UTF-8';  -- ok
+RESET lc_numeric;  -- ok
+ALTER SYSTEM SET lc_numeric = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_numeric"
+ALTER SYSTEM RESET lc_numeric;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_numeric"
+SET lc_time = 'en_US.UTF-8';  -- ok
+RESET lc_time;  -- ok
+ALTER SYSTEM SET lc_time = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_time"
+ALTER SYSTEM RESET lc_time;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_time"
+SET timezone_abbreviations = 'Default';  -- ok
+RESET timezone_abbreviations;  -- ok
+ALTER SYSTEM SET timezone_abbreviations = 'Default';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone_abbreviations"
+ALTER SYSTEM RESET timezone_abbreviations;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone_abbreviations"
+-- PGC_USERSET / CLIENT_CONN_OTHER
+SET gin_fuzzy_search_limit = 50;  -- ok
+RESET gin_fuzzy_search_limit;  -- ok
+ALTER SYSTEM SET gin_fuzzy_search_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_fuzzy_search_limit"
+ALTER SYSTEM RESET gin_fuzzy_search_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_fuzzy_search_limit"
+-- PGC_USERSET / CLIENT_CONN_PRELOAD
+SET local_preload_libraries = 'gssapi_krb5';  -- ok
+RESET local_preload_libraries;  -- ok
+ALTER SYSTEM SET local_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "local_preload_libraries"
+ALTER SYSTEM RESET local_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "local_preload_libraries"
+-- PGC_USERSET / CLIENT_CONN_STATEMENT
+SET bytea_output = 'hex';  -- ok
+RESET bytea_output;  -- ok
+ALTER SYSTEM SET bytea_output = 'hex';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bytea_output"
+ALTER SYSTEM RESET bytea_output;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bytea_output"
+SET check_function_bodies = OFF;  -- ok
+RESET check_function_bodies;  -- ok
+ALTER SYSTEM SET check_function_bodies = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "check_function_bodies"
+ALTER SYSTEM RESET check_function_bodies;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "check_function_bodies"
+SET client_min_messages = 'notice';  -- ok
+RESET client_min_messages;  -- ok
+ALTER SYSTEM SET client_min_messages = 'notice';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_min_messages"
+ALTER SYSTEM RESET client_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_min_messages"
+SET default_table_access_method = 'heap';  -- ok
+RESET default_table_access_method;  -- ok
+ALTER SYSTEM SET default_table_access_method = 'heap';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_table_access_method"
+ALTER SYSTEM RESET default_table_access_method;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_table_access_method"
+SET default_toast_compression = 'pglz';  -- ok
+RESET default_toast_compression;  -- ok
+ALTER SYSTEM SET default_toast_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_toast_compression"
+ALTER SYSTEM RESET default_toast_compression;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_toast_compression"
+SET default_transaction_deferrable = OFF;  -- ok
+RESET default_transaction_deferrable;  -- ok
+ALTER SYSTEM SET default_transaction_deferrable = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_deferrable"
+ALTER SYSTEM RESET default_transaction_deferrable;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_deferrable"
+SET default_transaction_isolation = 'read committed';  -- ok
+RESET default_transaction_isolation;  -- ok
+ALTER SYSTEM SET default_transaction_isolation = 'read committed';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_isolation"
+ALTER SYSTEM RESET default_transaction_isolation;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_isolation"
+SET default_transaction_read_only = OFF;  -- ok
+RESET default_transaction_read_only;  -- ok
+ALTER SYSTEM SET default_transaction_read_only = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_read_only"
+ALTER SYSTEM RESET default_transaction_read_only;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_read_only"
+SET gin_pending_list_limit = 1073741855;  -- ok
+RESET gin_pending_list_limit;  -- ok
+ALTER SYSTEM SET gin_pending_list_limit = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_pending_list_limit"
+ALTER SYSTEM RESET gin_pending_list_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_pending_list_limit"
+SET idle_in_transaction_session_timeout = 50;  -- ok
+RESET idle_in_transaction_session_timeout;  -- ok
+ALTER SYSTEM SET idle_in_transaction_session_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_in_transaction_session_timeout"
+ALTER SYSTEM RESET idle_in_transaction_session_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_in_transaction_session_timeout"
+SET idle_session_timeout = 50;  -- ok
+RESET idle_session_timeout;  -- ok
+ALTER SYSTEM SET idle_session_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_session_timeout"
+ALTER SYSTEM RESET idle_session_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_session_timeout"
+SET lock_timeout = 50;  -- ok
+RESET lock_timeout;  -- ok
+ALTER SYSTEM SET lock_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lock_timeout"
+ALTER SYSTEM RESET lock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lock_timeout"
+SET row_security = OFF;  -- ok
+RESET row_security;  -- ok
+ALTER SYSTEM SET row_security = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "row_security"
+ALTER SYSTEM RESET row_security;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "row_security"
+SET search_path = '"$user", public';  -- ok
+RESET search_path;  -- ok
+ALTER SYSTEM SET search_path = '"$user", public';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "search_path"
+ALTER SYSTEM RESET search_path;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "search_path"
+SET statement_timeout = 5250;  -- ok
+RESET statement_timeout;  -- ok
+ALTER SYSTEM SET statement_timeout = 5250;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "statement_timeout"
+ALTER SYSTEM RESET statement_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "statement_timeout"
+SET transaction_deferrable = OFF;  -- ok
+RESET transaction_deferrable;  -- ok
+SET transaction_read_only = OFF;  -- ok
+RESET transaction_read_only;  -- ok
+SET vacuum_failsafe_age = 50;  -- ok
+RESET vacuum_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_failsafe_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_failsafe_age"
+ALTER SYSTEM RESET vacuum_failsafe_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_failsafe_age"
+SET vacuum_freeze_min_age = 50;  -- ok
+RESET vacuum_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_min_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_min_age"
+ALTER SYSTEM RESET vacuum_freeze_min_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_min_age"
+SET vacuum_freeze_table_age = 50;  -- ok
+RESET vacuum_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_table_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_table_age"
+ALTER SYSTEM RESET vacuum_freeze_table_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_table_age"
+SET vacuum_multixact_failsafe_age = 50;  -- ok
+RESET vacuum_multixact_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_failsafe_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_failsafe_age"
+ALTER SYSTEM RESET vacuum_multixact_failsafe_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_failsafe_age"
+SET vacuum_multixact_freeze_min_age = 50;  -- ok
+RESET vacuum_multixact_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_min_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_min_age"
+ALTER SYSTEM RESET vacuum_multixact_freeze_min_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_min_age"
+SET vacuum_multixact_freeze_table_age = 50;  -- ok
+RESET vacuum_multixact_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_table_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_table_age"
+ALTER SYSTEM RESET vacuum_multixact_freeze_table_age;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_table_age"
+SET xmlbinary = 'base64';  -- ok
+RESET xmlbinary;  -- ok
+ALTER SYSTEM SET xmlbinary = 'base64';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmlbinary"
+ALTER SYSTEM RESET xmlbinary;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmlbinary"
+SET xmloption = 'content';  -- ok
+RESET xmloption;  -- ok
+ALTER SYSTEM SET xmloption = 'content';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmloption"
+ALTER SYSTEM RESET xmloption;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmloption"
+-- PGC_USERSET / COMPAT_OPTIONS_PREVIOUS
+SET escape_string_warning = OFF;  -- ok
+RESET escape_string_warning;  -- ok
+ALTER SYSTEM SET escape_string_warning = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "escape_string_warning"
+ALTER SYSTEM RESET escape_string_warning;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "escape_string_warning"
+SET array_nulls = OFF;  -- ok
+RESET array_nulls;  -- ok
+ALTER SYSTEM SET array_nulls = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "array_nulls"
+ALTER SYSTEM RESET array_nulls;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "array_nulls"
+SET quote_all_identifiers = OFF;  -- ok
+RESET quote_all_identifiers;  -- ok
+ALTER SYSTEM SET quote_all_identifiers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "quote_all_identifiers"
+ALTER SYSTEM RESET quote_all_identifiers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "quote_all_identifiers"
+SET standard_conforming_strings = OFF;  -- ok
+RESET standard_conforming_strings;  -- ok
+ALTER SYSTEM SET standard_conforming_strings = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "standard_conforming_strings"
+ALTER SYSTEM RESET standard_conforming_strings;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "standard_conforming_strings"
+SET synchronize_seqscans = OFF;  -- ok
+RESET synchronize_seqscans;  -- ok
+ALTER SYSTEM SET synchronize_seqscans = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronize_seqscans"
+ALTER SYSTEM RESET synchronize_seqscans;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronize_seqscans"
+-- PGC_USERSET / CONN_AUTH_AUTH
+SET password_encryption = 'scram-sha-256';  -- ok
+RESET password_encryption;  -- ok
+ALTER SYSTEM SET password_encryption = 'scram-sha-256';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "password_encryption"
+ALTER SYSTEM RESET password_encryption;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "password_encryption"
+-- PGC_USERSET / CONN_AUTH_SETTINGS
+SET client_connection_check_interval = 0;  -- ok
+RESET client_connection_check_interval;  -- ok
+ALTER SYSTEM SET client_connection_check_interval = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_connection_check_interval"
+ALTER SYSTEM RESET client_connection_check_interval;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_connection_check_interval"
+SET tcp_keepalives_count = 50;  -- ok
+RESET tcp_keepalives_count;  -- ok
+ALTER SYSTEM SET tcp_keepalives_count = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_count"
+ALTER SYSTEM RESET tcp_keepalives_count;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_count"
+SET tcp_keepalives_idle = 50;  -- ok
+RESET tcp_keepalives_idle;  -- ok
+ALTER SYSTEM SET tcp_keepalives_idle = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_idle"
+ALTER SYSTEM RESET tcp_keepalives_idle;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_idle"
+SET tcp_keepalives_interval = 50;  -- ok
+RESET tcp_keepalives_interval;  -- ok
+ALTER SYSTEM SET tcp_keepalives_interval = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_interval"
+ALTER SYSTEM RESET tcp_keepalives_interval;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_interval"
+SET tcp_user_timeout = 50;  -- ok
+RESET tcp_user_timeout;  -- ok
+ALTER SYSTEM SET tcp_user_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_user_timeout"
+ALTER SYSTEM RESET tcp_user_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_user_timeout"
+-- PGC_USERSET / CONN_AUTH_SSL
+SET ssl_renegotiation_limit = 0;  -- ok
+RESET ssl_renegotiation_limit;  -- ok
+-- PGC_USERSET / DEVELOPER_OPTIONS
+SET force_parallel_mode = 'off';  -- ok
+RESET force_parallel_mode;  -- ok
+ALTER SYSTEM SET force_parallel_mode = 'off';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "force_parallel_mode"
+ALTER SYSTEM RESET force_parallel_mode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "force_parallel_mode"
+SET jit_expressions = OFF;  -- ok
+RESET jit_expressions;  -- ok
+ALTER SYSTEM SET jit_expressions = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_expressions"
+ALTER SYSTEM RESET jit_expressions;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_expressions"
+SET jit_tuple_deforming = OFF;  -- ok
+RESET jit_tuple_deforming;  -- ok
+ALTER SYSTEM SET jit_tuple_deforming = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_tuple_deforming"
+ALTER SYSTEM RESET jit_tuple_deforming;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_tuple_deforming"
+SET trace_notify = OFF;  -- ok
+RESET trace_notify;  -- ok
+ALTER SYSTEM SET trace_notify = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_notify"
+ALTER SYSTEM RESET trace_notify;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_notify"
+SET trace_sort = OFF;  -- ok
+RESET trace_sort;  -- ok
+ALTER SYSTEM SET trace_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_sort"
+ALTER SYSTEM RESET trace_sort;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_sort"
+-- PGC_USERSET / ERROR_HANDLING_OPTIONS
+SET exit_on_error = OFF;  -- ok
+RESET exit_on_error;  -- ok
+ALTER SYSTEM SET exit_on_error = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "exit_on_error"
+ALTER SYSTEM RESET exit_on_error;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "exit_on_error"
+-- PGC_USERSET / LOGGING_WHAT
+SET application_name = 'psql';  -- ok
+RESET application_name;  -- ok
+ALTER SYSTEM SET application_name = 'psql';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "application_name"
+ALTER SYSTEM RESET application_name;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "application_name"
+SET debug_pretty_print = OFF;  -- ok
+RESET debug_pretty_print;  -- ok
+ALTER SYSTEM SET debug_pretty_print = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_pretty_print"
+ALTER SYSTEM RESET debug_pretty_print;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_pretty_print"
+SET debug_print_parse = OFF;  -- ok
+RESET debug_print_parse;  -- ok
+ALTER SYSTEM SET debug_print_parse = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_parse"
+ALTER SYSTEM RESET debug_print_parse;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_parse"
+SET debug_print_plan = OFF;  -- ok
+RESET debug_print_plan;  -- ok
+ALTER SYSTEM SET debug_print_plan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_plan"
+ALTER SYSTEM RESET debug_print_plan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_plan"
+SET debug_print_rewritten = OFF;  -- ok
+RESET debug_print_rewritten;  -- ok
+ALTER SYSTEM SET debug_print_rewritten = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_rewritten"
+ALTER SYSTEM RESET debug_print_rewritten;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_rewritten"
+SET log_parameter_max_length_on_error = 50;  -- ok
+RESET log_parameter_max_length_on_error;  -- ok
+ALTER SYSTEM SET log_parameter_max_length_on_error = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length_on_error"
+ALTER SYSTEM RESET log_parameter_max_length_on_error;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length_on_error"
+-- PGC_USERSET / QUERY_TUNING_COST
+SET cpu_index_tuple_cost = 50;  -- ok
+RESET cpu_index_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_index_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_index_tuple_cost"
+ALTER SYSTEM RESET cpu_index_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_index_tuple_cost"
+SET cpu_operator_cost = 50;  -- ok
+RESET cpu_operator_cost;  -- ok
+ALTER SYSTEM SET cpu_operator_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_operator_cost"
+ALTER SYSTEM RESET cpu_operator_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_operator_cost"
+SET cpu_tuple_cost = 50;  -- ok
+RESET cpu_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_tuple_cost"
+ALTER SYSTEM RESET cpu_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_tuple_cost"
+SET effective_cache_size = 1073741824;  -- ok
+RESET effective_cache_size;  -- ok
+ALTER SYSTEM SET effective_cache_size = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_cache_size"
+ALTER SYSTEM RESET effective_cache_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_cache_size"
+SET jit_above_cost = 50;  -- ok
+RESET jit_above_cost;  -- ok
+ALTER SYSTEM SET jit_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_above_cost"
+ALTER SYSTEM RESET jit_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_above_cost"
+SET jit_inline_above_cost = 50;  -- ok
+RESET jit_inline_above_cost;  -- ok
+ALTER SYSTEM SET jit_inline_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_inline_above_cost"
+ALTER SYSTEM RESET jit_inline_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_inline_above_cost"
+SET jit_optimize_above_cost = 50;  -- ok
+RESET jit_optimize_above_cost;  -- ok
+ALTER SYSTEM SET jit_optimize_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_optimize_above_cost"
+ALTER SYSTEM RESET jit_optimize_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_optimize_above_cost"
+SET min_parallel_index_scan_size = 50;  -- ok
+RESET min_parallel_index_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_index_scan_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_index_scan_size"
+ALTER SYSTEM RESET min_parallel_index_scan_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_index_scan_size"
+SET min_parallel_table_scan_size = 50;  -- ok
+RESET min_parallel_table_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_table_scan_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_table_scan_size"
+ALTER SYSTEM RESET min_parallel_table_scan_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_table_scan_size"
+SET parallel_setup_cost = 50;  -- ok
+RESET parallel_setup_cost;  -- ok
+ALTER SYSTEM SET parallel_setup_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_setup_cost"
+ALTER SYSTEM RESET parallel_setup_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_setup_cost"
+SET parallel_tuple_cost = 50;  -- ok
+RESET parallel_tuple_cost;  -- ok
+ALTER SYSTEM SET parallel_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_tuple_cost"
+ALTER SYSTEM RESET parallel_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_tuple_cost"
+SET random_page_cost = 50;  -- ok
+RESET random_page_cost;  -- ok
+ALTER SYSTEM SET random_page_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "random_page_cost"
+ALTER SYSTEM RESET random_page_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "random_page_cost"
+SET seq_page_cost = 50;  -- ok
+RESET seq_page_cost;  -- ok
+ALTER SYSTEM SET seq_page_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "seq_page_cost"
+ALTER SYSTEM RESET seq_page_cost;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "seq_page_cost"
+-- PGC_USERSET / QUERY_TUNING_GEQO
+SET geqo = OFF;  -- ok
+RESET geqo;  -- ok
+ALTER SYSTEM SET geqo = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo"
+ALTER SYSTEM RESET geqo;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo"
+SET geqo_effort = 5;  -- ok
+RESET geqo_effort;  -- ok
+ALTER SYSTEM SET geqo_effort = 5;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_effort"
+ALTER SYSTEM RESET geqo_effort;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_effort"
+SET geqo_generations = 50;  -- ok
+RESET geqo_generations;  -- ok
+ALTER SYSTEM SET geqo_generations = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_generations"
+ALTER SYSTEM RESET geqo_generations;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_generations"
+SET geqo_pool_size = 50;  -- ok
+RESET geqo_pool_size;  -- ok
+ALTER SYSTEM SET geqo_pool_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_pool_size"
+ALTER SYSTEM RESET geqo_pool_size;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_pool_size"
+SET geqo_seed = 0;  -- ok
+RESET geqo_seed;  -- ok
+ALTER SYSTEM SET geqo_seed = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_seed"
+ALTER SYSTEM RESET geqo_seed;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_seed"
+SET geqo_selection_bias = 2;  -- ok
+RESET geqo_selection_bias;  -- ok
+ALTER SYSTEM SET geqo_selection_bias = 2;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_selection_bias"
+ALTER SYSTEM RESET geqo_selection_bias;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_selection_bias"
+SET geqo_threshold = 1073741824;  -- ok
+RESET geqo_threshold;  -- ok
+ALTER SYSTEM SET geqo_threshold = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_threshold"
+ALTER SYSTEM RESET geqo_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_threshold"
+-- PGC_USERSET / QUERY_TUNING_METHOD
+SET enable_async_append = OFF;  -- ok
+RESET enable_async_append;  -- ok
+ALTER SYSTEM SET enable_async_append = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_async_append"
+ALTER SYSTEM RESET enable_async_append;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_async_append"
+SET enable_bitmapscan = OFF;  -- ok
+RESET enable_bitmapscan;  -- ok
+ALTER SYSTEM SET enable_bitmapscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_bitmapscan"
+ALTER SYSTEM RESET enable_bitmapscan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_bitmapscan"
+SET enable_gathermerge = OFF;  -- ok
+RESET enable_gathermerge;  -- ok
+ALTER SYSTEM SET enable_gathermerge = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_gathermerge"
+ALTER SYSTEM RESET enable_gathermerge;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_gathermerge"
+SET enable_hashagg = OFF;  -- ok
+RESET enable_hashagg;  -- ok
+ALTER SYSTEM SET enable_hashagg = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashagg"
+ALTER SYSTEM RESET enable_hashagg;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashagg"
+SET enable_hashjoin = OFF;  -- ok
+RESET enable_hashjoin;  -- ok
+ALTER SYSTEM SET enable_hashjoin = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashjoin"
+ALTER SYSTEM RESET enable_hashjoin;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashjoin"
+SET enable_incremental_sort = OFF;  -- ok
+RESET enable_incremental_sort;  -- ok
+ALTER SYSTEM SET enable_incremental_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_incremental_sort"
+ALTER SYSTEM RESET enable_incremental_sort;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_incremental_sort"
+SET enable_indexonlyscan = OFF;  -- ok
+RESET enable_indexonlyscan;  -- ok
+ALTER SYSTEM SET enable_indexonlyscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexonlyscan"
+ALTER SYSTEM RESET enable_indexonlyscan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexonlyscan"
+SET enable_indexscan = OFF;  -- ok
+RESET enable_indexscan;  -- ok
+ALTER SYSTEM SET enable_indexscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexscan"
+ALTER SYSTEM RESET enable_indexscan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexscan"
+SET enable_material = OFF;  -- ok
+RESET enable_material;  -- ok
+ALTER SYSTEM SET enable_material = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_material"
+ALTER SYSTEM RESET enable_material;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_material"
+SET enable_memoize = OFF;  -- ok
+RESET enable_memoize;  -- ok
+ALTER SYSTEM SET enable_memoize = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_memoize"
+ALTER SYSTEM RESET enable_memoize;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_memoize"
+SET enable_mergejoin = OFF;  -- ok
+RESET enable_mergejoin;  -- ok
+ALTER SYSTEM SET enable_mergejoin = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_mergejoin"
+ALTER SYSTEM RESET enable_mergejoin;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_mergejoin"
+SET enable_nestloop = OFF;  -- ok
+RESET enable_nestloop;  -- ok
+ALTER SYSTEM SET enable_nestloop = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_nestloop"
+ALTER SYSTEM RESET enable_nestloop;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_nestloop"
+SET enable_parallel_append = OFF;  -- ok
+RESET enable_parallel_append;  -- ok
+ALTER SYSTEM SET enable_parallel_append = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_append"
+ALTER SYSTEM RESET enable_parallel_append;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_append"
+SET enable_parallel_hash = OFF;  -- ok
+RESET enable_parallel_hash;  -- ok
+ALTER SYSTEM SET enable_parallel_hash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_hash"
+ALTER SYSTEM RESET enable_parallel_hash;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_hash"
+SET enable_partition_pruning = OFF;  -- ok
+RESET enable_partition_pruning;  -- ok
+ALTER SYSTEM SET enable_partition_pruning = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partition_pruning"
+ALTER SYSTEM RESET enable_partition_pruning;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partition_pruning"
+SET enable_partitionwise_aggregate = OFF;  -- ok
+RESET enable_partitionwise_aggregate;  -- ok
+ALTER SYSTEM SET enable_partitionwise_aggregate = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_aggregate"
+ALTER SYSTEM RESET enable_partitionwise_aggregate;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_aggregate"
+SET enable_partitionwise_join = OFF;  -- ok
+RESET enable_partitionwise_join;  -- ok
+ALTER SYSTEM SET enable_partitionwise_join = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_join"
+ALTER SYSTEM RESET enable_partitionwise_join;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_join"
+SET enable_seqscan = OFF;  -- ok
+RESET enable_seqscan;  -- ok
+ALTER SYSTEM SET enable_seqscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_seqscan"
+ALTER SYSTEM RESET enable_seqscan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_seqscan"
+SET enable_sort = OFF;  -- ok
+RESET enable_sort;  -- ok
+ALTER SYSTEM SET enable_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_sort"
+ALTER SYSTEM RESET enable_sort;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_sort"
+SET enable_tidscan = OFF;  -- ok
+RESET enable_tidscan;  -- ok
+ALTER SYSTEM SET enable_tidscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_tidscan"
+ALTER SYSTEM RESET enable_tidscan;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_tidscan"
+-- PGC_USERSET / QUERY_TUNING_OTHER
+SET constraint_exclusion = 'partition';  -- ok
+RESET constraint_exclusion;  -- ok
+ALTER SYSTEM SET constraint_exclusion = 'partition';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "constraint_exclusion"
+ALTER SYSTEM RESET constraint_exclusion;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "constraint_exclusion"
+SET cursor_tuple_fraction = 0;  -- ok
+RESET cursor_tuple_fraction;  -- ok
+ALTER SYSTEM SET cursor_tuple_fraction = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cursor_tuple_fraction"
+ALTER SYSTEM RESET cursor_tuple_fraction;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cursor_tuple_fraction"
+SET default_statistics_target = 5000;  -- ok
+RESET default_statistics_target;  -- ok
+ALTER SYSTEM SET default_statistics_target = 5000;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_statistics_target"
+ALTER SYSTEM RESET default_statistics_target;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_statistics_target"
+SET from_collapse_limit = 1073741824;  -- ok
+RESET from_collapse_limit;  -- ok
+ALTER SYSTEM SET from_collapse_limit = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "from_collapse_limit"
+ALTER SYSTEM RESET from_collapse_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "from_collapse_limit"
+SET jit = OFF;  -- ok
+RESET jit;  -- ok
+ALTER SYSTEM SET jit = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit"
+ALTER SYSTEM RESET jit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit"
+SET join_collapse_limit = 1073741824;  -- ok
+RESET join_collapse_limit;  -- ok
+ALTER SYSTEM SET join_collapse_limit = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "join_collapse_limit"
+ALTER SYSTEM RESET join_collapse_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "join_collapse_limit"
+SET plan_cache_mode = 'force_generic_plan';  -- ok
+RESET plan_cache_mode;  -- ok
+ALTER SYSTEM SET plan_cache_mode = 'force_generic_plan';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "plan_cache_mode"
+ALTER SYSTEM RESET plan_cache_mode;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "plan_cache_mode"
+-- PGC_USERSET / REPLICATION_SENDING
+SET wal_sender_timeout = 50;  -- ok
+RESET wal_sender_timeout;  -- ok
+ALTER SYSTEM SET wal_sender_timeout = 50;  -- ok
+ALTER SYSTEM RESET wal_sender_timeout;  -- ok
+-- PGC_USERSET / RESOURCES_ASYNCHRONOUS
+SET backend_flush_after = 128;  -- ok
+RESET backend_flush_after;  -- ok
+ALTER SYSTEM SET backend_flush_after = 128;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backend_flush_after"
+ALTER SYSTEM RESET backend_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backend_flush_after"
+SET effective_io_concurrency = 0;  -- ok
+RESET effective_io_concurrency;  -- ok
+ALTER SYSTEM SET effective_io_concurrency = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_io_concurrency"
+ALTER SYSTEM RESET effective_io_concurrency;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_io_concurrency"
+SET maintenance_io_concurrency = 0;  -- ok
+RESET maintenance_io_concurrency;  -- ok
+ALTER SYSTEM SET maintenance_io_concurrency = 0;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_io_concurrency"
+ALTER SYSTEM RESET maintenance_io_concurrency;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_io_concurrency"
+SET max_parallel_maintenance_workers = 50;  -- ok
+RESET max_parallel_maintenance_workers;  -- ok
+ALTER SYSTEM SET max_parallel_maintenance_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_maintenance_workers"
+ALTER SYSTEM RESET max_parallel_maintenance_workers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_maintenance_workers"
+SET max_parallel_workers = 50;  -- ok
+RESET max_parallel_workers;  -- ok
+ALTER SYSTEM SET max_parallel_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers"
+ALTER SYSTEM RESET max_parallel_workers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers"
+SET max_parallel_workers_per_gather = 50;  -- ok
+RESET max_parallel_workers_per_gather;  -- ok
+ALTER SYSTEM SET max_parallel_workers_per_gather = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers_per_gather"
+ALTER SYSTEM RESET max_parallel_workers_per_gather;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers_per_gather"
+SET parallel_leader_participation = OFF;  -- ok
+RESET parallel_leader_participation;  -- ok
+ALTER SYSTEM SET parallel_leader_participation = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_leader_participation"
+ALTER SYSTEM RESET parallel_leader_participation;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_leader_participation"
+-- PGC_USERSET / RESOURCES_MEM
+SET hash_mem_multiplier = 500;  -- ok
+RESET hash_mem_multiplier;  -- ok
+ALTER SYSTEM SET hash_mem_multiplier = 500;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hash_mem_multiplier"
+ALTER SYSTEM RESET hash_mem_multiplier;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hash_mem_multiplier"
+SET logical_decoding_work_mem = 1073741855;  -- ok
+RESET logical_decoding_work_mem;  -- ok
+ALTER SYSTEM SET logical_decoding_work_mem = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logical_decoding_work_mem"
+ALTER SYSTEM RESET logical_decoding_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logical_decoding_work_mem"
+SET maintenance_work_mem = 1073742335;  -- ok
+RESET maintenance_work_mem;  -- ok
+ALTER SYSTEM SET maintenance_work_mem = 1073742335;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_work_mem"
+ALTER SYSTEM RESET maintenance_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_work_mem"
+SET temp_buffers = 536870961;  -- ok
+RESET temp_buffers;  -- ok
+ALTER SYSTEM SET temp_buffers = 536870961;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_buffers"
+ALTER SYSTEM RESET temp_buffers;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_buffers"
+SET work_mem = 1073741855;  -- ok
+RESET work_mem;  -- ok
+ALTER SYSTEM SET work_mem = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "work_mem"
+ALTER SYSTEM RESET work_mem;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "work_mem"
+-- PGC_USERSET / RESOURCES_VACUUM_DELAY
+SET vacuum_cost_delay = 50;  -- ok
+RESET vacuum_cost_delay;  -- ok
+ALTER SYSTEM SET vacuum_cost_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_delay"
+ALTER SYSTEM RESET vacuum_cost_delay;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_delay"
+SET vacuum_cost_limit = 5000;  -- ok
+RESET vacuum_cost_limit;  -- ok
+ALTER SYSTEM SET vacuum_cost_limit = 5000;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_limit"
+ALTER SYSTEM RESET vacuum_cost_limit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_limit"
+SET vacuum_cost_page_dirty = 50;  -- ok
+RESET vacuum_cost_page_dirty;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_dirty = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_dirty"
+ALTER SYSTEM RESET vacuum_cost_page_dirty;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_dirty"
+SET vacuum_cost_page_hit = 50;  -- ok
+RESET vacuum_cost_page_hit;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_hit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_hit"
+ALTER SYSTEM RESET vacuum_cost_page_hit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_hit"
+SET vacuum_cost_page_miss = 50;  -- ok
+RESET vacuum_cost_page_miss;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_miss = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_miss"
+ALTER SYSTEM RESET vacuum_cost_page_miss;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_miss"
+-- PGC_USERSET / UNGROUPED
+SET seed = 0;  -- ok
+RESET seed;  -- ok
+-- PGC_USERSET / WAL_SETTINGS
+SET commit_siblings = 50;  -- ok
+RESET commit_siblings;  -- ok
+ALTER SYSTEM SET commit_siblings = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_siblings"
+ALTER SYSTEM RESET commit_siblings;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_siblings"
+SET synchronous_commit = 'remote_write';  -- ok
+RESET synchronous_commit;  -- ok
+ALTER SYSTEM SET synchronous_commit = 'remote_write';  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_commit"
+ALTER SYSTEM RESET synchronous_commit;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_commit"
+SET wal_skip_threshold = 50;  -- ok
+RESET wal_skip_threshold;  -- ok
+ALTER SYSTEM SET wal_skip_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_skip_threshold"
+ALTER SYSTEM RESET wal_skip_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_skip_threshold"
+RESET statement_timeout;
+RESET SESSION AUTHORIZATION;
+DROP ROLE regress_replication_admin;
diff --git a/src/test/regress/parallel_schedule b/src/test/regress/parallel_schedule
index 4040d845e4..4a6f8404c3 100644
--- a/src/test/regress/parallel_schedule
+++ b/src/test/regress/parallel_schedule
@@ -91,7 +91,7 @@ test: create_table_like alter_generic alter_operator misc async dbsize misc_func
 # ----------
 # Another group of parallel tests (GUC management roles related)
 # ----------
-test: admin host_resource_settings vacuum_settings autovacuum_settings logging_settings
+test: admin host_resource_settings vacuum_settings autovacuum_settings logging_settings replication_settings
 
 # rules cannot run concurrently with any test that creates
 # a view or rule in the public schema
diff --git a/src/test/regress/sql/replication_settings.sql b/src/test/regress/sql/replication_settings.sql
new file mode 100644
index 0000000000..a231bbd368
--- /dev/null
+++ b/src/test/regress/sql/replication_settings.sql
@@ -0,0 +1,1051 @@
+-- Non-superuser with privileges to configure replication settings
+CREATE ROLE regress_replication_admin NOSUPERUSER;
+GRANT pg_manage_replication_settings TO regress_replication_admin;
+-- Perform all operations as user 'regress_replication_admin' --
+SET SESSION AUTHORIZATION regress_replication_admin;
+-- PGC_BACKEND / DEVELOPER_OPTIONS
+ALTER SYSTEM SET ignore_system_indexes = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_system_indexes;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET post_auth_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET post_auth_delay;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_INTERNAL / PRESET_OPTIONS
+-- PGC_INTERNAL / UNGROUPED
+-- PGC_POSTMASTER / AUTOVACUUM
+ALTER SYSTEM SET autovacuum_freeze_max_age = 1000050000;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_freeze_max_age;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_max_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_max_workers;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_multixact_freeze_max_age = 1000005000;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_multixact_freeze_max_age;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / CLIENT_CONN_PRELOAD
+ALTER SYSTEM SET jit_provider = 'llvmjit';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_provider;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET shared_preload_libraries = 'iconv, pcre';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET shared_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / CONN_AUTH_SETTINGS
+ALTER SYSTEM SET bonjour = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bonjour;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET bonjour_name = 'BonneNuit';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bonjour_name;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET listen_addresses = 'localhost';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET listen_addresses;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_connections = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_connections;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET port = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET port;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET superuser_reserved_connections = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET superuser_reserved_connections;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET unix_socket_directories = '/tmp';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_directories;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET unix_socket_group = 'tenant';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_group;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET unix_socket_permissions = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_permissions;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / DEVELOPER_OPTIONS
+ALTER SYSTEM SET ignore_invalid_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_invalid_pages;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / ERROR_HANDLING_OPTIONS
+ALTER SYSTEM SET data_sync_retry = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET data_sync_retry;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / FILE_LOCATIONS
+ALTER SYSTEM SET external_pid_file = '/var/postgres/master.pid';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET external_pid_file;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / LOCK_MANAGEMENT
+ALTER SYSTEM SET max_locks_per_transaction = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_locks_per_transaction;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_pred_locks_per_transaction = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_transaction;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / LOGGING_WHERE
+ALTER SYSTEM SET event_source = 'PostgreSQL';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET event_source;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET logging_collector = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET logging_collector;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / PROCESS_TITLE
+ALTER SYSTEM SET cluster_name = 'BonCluster';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET cluster_name;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / REPLICATION_SENDING
+ALTER SYSTEM SET max_replication_slots = 50;  -- ok
+ALTER SYSTEM RESET max_replication_slots;  -- ok
+ALTER SYSTEM SET max_wal_senders = 50;  -- ok
+ALTER SYSTEM RESET max_wal_senders;  -- ok
+ALTER SYSTEM SET track_commit_timestamp = OFF;  -- ok
+ALTER SYSTEM RESET track_commit_timestamp;  -- ok
+-- PGC_POSTMASTER / REPLICATION_STANDBY
+ALTER SYSTEM SET hot_standby = OFF;  -- ok
+ALTER SYSTEM RESET hot_standby;  -- ok
+-- PGC_POSTMASTER / REPLICATION_SUBSCRIBERS
+ALTER SYSTEM SET max_logical_replication_workers = 50;  -- ok
+ALTER SYSTEM RESET max_logical_replication_workers;  -- ok
+-- PGC_POSTMASTER / RESOURCES_ASYNCHRONOUS
+ALTER SYSTEM SET max_worker_processes = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_worker_processes;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET old_snapshot_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET old_snapshot_threshold;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / RESOURCES_KERNEL
+ALTER SYSTEM SET max_files_per_process = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_files_per_process;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / RESOURCES_MEM
+ALTER SYSTEM SET dynamic_shared_memory_type = 'posix';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET dynamic_shared_memory_type;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET huge_pages = 'try';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET huge_pages;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_prepared_transactions = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_prepared_transactions;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET min_dynamic_shared_memory = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET min_dynamic_shared_memory;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET shared_buffers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET shared_buffers;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET shared_memory_type = 'mmap';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET shared_memory_type;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / STATS_COLLECTOR
+ALTER SYSTEM SET track_activity_query_size = 524338;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_activity_query_size;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_ARCHIVING
+ALTER SYSTEM SET archive_mode = 'off';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET archive_mode;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_RECOVERY_TARGET
+ALTER SYSTEM SET recovery_target_action = 'pause';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_action;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_inclusive = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_inclusive;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_lsn = '16/B374D848';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_lsn;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_name = 'BonPoint';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_name;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_time;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_timeline = 'latest';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_timeline;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_target_xid = '12345678';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_xid;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_SETTINGS
+ALTER SYSTEM SET wal_buffers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_buffers;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_level = 'replica';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_level;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_log_hints = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_log_hints;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / AUTOVACUUM
+ALTER SYSTEM SET autovacuum = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_analyze_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_analyze_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_analyze_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_analyze_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_naptime = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_naptime;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_cost_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_cost_delay;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_cost_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_cost_limit;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_insert_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_insert_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_insert_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_insert_threshold;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_scale_factor = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_scale_factor;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET autovacuum_vacuum_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_vacuum_threshold;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / CONN_AUTH_AUTH
+ALTER SYSTEM SET authentication_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET authentication_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET db_user_namespace = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET db_user_namespace;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET krb_caseins_users = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET krb_caseins_users;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET krb_server_keyfile = 'krb/server.key';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET krb_server_keyfile;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / CONN_AUTH_SSL
+ALTER SYSTEM SET ssl_ca_file = 'ca/server.ca';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ca_file;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_cert_file = 'crt/server.crt';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_cert_file;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_ciphers = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ciphers;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_crl_dir = 'crl/';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_crl_dir;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_crl_file = 'crl/server.crl';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_crl_file;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_dh_params_file = 'ssl/params';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_dh_params_file;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_ecdh_curve = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ecdh_curve;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_key_file = 'crl/server.key';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_key_file;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_min_protocol_version;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_passphrase_command = '/bin/passphrase';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_passphrase_command;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_passphrase_command_supports_reload = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_passphrase_command_supports_reload;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ssl_prefer_server_ciphers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_prefer_server_ciphers;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / DEVELOPER_OPTIONS
+ALTER SYSTEM SET pre_auth_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET pre_auth_delay;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET remove_temp_files_after_crash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET remove_temp_files_after_crash;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET trace_recovery_messages = 'log';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET trace_recovery_messages;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / ERROR_HANDLING_OPTIONS
+ALTER SYSTEM SET recovery_init_sync_method = 'fsync';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_init_sync_method;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET restart_after_crash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET restart_after_crash;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / LOCK_MANAGEMENT
+ALTER SYSTEM SET max_pred_locks_per_page = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_page;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_pred_locks_per_relation = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_relation;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / LOGGING_WHAT
+ALTER SYSTEM SET log_autovacuum_min_duration = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_autovacuum_min_duration;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_checkpoints = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_checkpoints;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_hostname = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_hostname;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_line_prefix = '%m [%p] ';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_line_prefix;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_recovery_conflict_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_recovery_conflict_waits;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_timezone = 'Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_timezone;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / LOGGING_WHERE
+ALTER SYSTEM SET log_directory = 'log';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_directory;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_file_mode = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_file_mode;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_filename;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_rotation_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_rotation_age;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_rotation_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_rotation_size;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_truncate_on_rotation = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_truncate_on_rotation;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET syslog_ident = 'postgres';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_ident;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET syslog_sequence_numbers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_sequence_numbers;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET syslog_split_messages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_split_messages;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / REPLICATION_PRIMARY
+ALTER SYSTEM SET synchronous_standby_names = 'fee, fi, fo, fum';  -- ok
+ALTER SYSTEM RESET synchronous_standby_names;  -- ok
+ALTER SYSTEM SET vacuum_defer_cleanup_age = 50;  -- ok
+ALTER SYSTEM RESET vacuum_defer_cleanup_age;  -- ok
+-- PGC_SIGHUP / REPLICATION_SENDING
+ALTER SYSTEM SET max_slot_wal_keep_size = 50;  -- ok
+ALTER SYSTEM RESET max_slot_wal_keep_size;  -- ok
+ALTER SYSTEM SET wal_keep_size = 50;  -- ok
+ALTER SYSTEM RESET wal_keep_size;  -- ok
+-- PGC_SIGHUP / REPLICATION_STANDBY
+ALTER SYSTEM SET hot_standby_feedback = OFF;  -- ok
+ALTER SYSTEM RESET hot_standby_feedback;  -- ok
+ALTER SYSTEM SET max_standby_archive_delay = 50;  -- ok
+ALTER SYSTEM RESET max_standby_archive_delay;  -- ok
+ALTER SYSTEM SET max_standby_streaming_delay = 50;  -- ok
+ALTER SYSTEM RESET max_standby_streaming_delay;  -- ok
+ALTER SYSTEM SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- ok
+ALTER SYSTEM RESET primary_conninfo;  -- ok
+ALTER SYSTEM SET primary_slot_name = 'bonne_fente';  -- ok
+ALTER SYSTEM RESET primary_slot_name;  -- ok
+ALTER SYSTEM SET promote_trigger_file = 'promote.trigger';  -- ok
+ALTER SYSTEM RESET promote_trigger_file;  -- ok
+ALTER SYSTEM SET recovery_min_apply_delay = 50;  -- ok
+ALTER SYSTEM RESET recovery_min_apply_delay;  -- ok
+ALTER SYSTEM SET wal_receiver_create_temp_slot = OFF;  -- ok
+ALTER SYSTEM RESET wal_receiver_create_temp_slot;  -- ok
+ALTER SYSTEM SET wal_receiver_status_interval = 50;  -- ok
+ALTER SYSTEM RESET wal_receiver_status_interval;  -- ok
+ALTER SYSTEM SET wal_receiver_timeout = 50;  -- ok
+ALTER SYSTEM RESET wal_receiver_timeout;  -- ok
+ALTER SYSTEM SET wal_retrieve_retry_interval = 50;  -- ok
+ALTER SYSTEM RESET wal_retrieve_retry_interval;  -- ok
+-- PGC_SIGHUP / REPLICATION_SUBSCRIBERS
+ALTER SYSTEM SET max_sync_workers_per_subscription = 50;  -- ok
+ALTER SYSTEM RESET max_sync_workers_per_subscription;  -- ok
+-- PGC_SIGHUP / RESOURCES_BGWRITER
+ALTER SYSTEM SET bgwriter_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_delay;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET bgwriter_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET bgwriter_lru_maxpages = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_lru_maxpages;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET bgwriter_lru_multiplier = 5;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_lru_multiplier;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / RESOURCES_MEM
+ALTER SYSTEM SET autovacuum_work_mem = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / STATS_COLLECTOR
+ALTER SYSTEM SET stats_temp_directory = 'pg_stat_tmp';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET stats_temp_directory;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_ARCHIVE_RECOVERY
+ALTER SYSTEM SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET archive_cleanup_command;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET recovery_end_command = '/bin/recover my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_end_command;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET restore_command = '/bin/restore my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET restore_command;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_ARCHIVING
+ALTER SYSTEM SET archive_command = '/bin/archive my stuff';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET archive_command;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET archive_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET archive_timeout;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_CHECKPOINTS
+ALTER SYSTEM SET checkpoint_warning = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_warning;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET checkpoint_completion_target = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_completion_target;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET checkpoint_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET checkpoint_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_wal_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_wal_size;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET min_wal_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET min_wal_size;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_SETTINGS
+ALTER SYSTEM SET fsync = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET fsync;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET full_page_writes = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET full_page_writes;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_sync_method = 'open_datasync';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_sync_method;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_writer_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_writer_delay;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_writer_flush_after = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_writer_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_LOCALE
+SET lc_messages = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+RESET lc_messages;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET lc_messages = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lc_messages;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_OTHER
+SET dynamic_library_path = '$libdir';  -- fail, regress_replication_admin has insufficient privileges
+RESET dynamic_library_path;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET dynamic_library_path = '$libdir';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET dynamic_library_path;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_PRELOAD
+SET session_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+RESET session_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET session_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET session_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_STATEMENT
+SET session_replication_role = 'origin';  -- fail, regress_replication_admin has insufficient privileges
+RESET session_replication_role;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET session_replication_role = 'origin';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET session_replication_role;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / COMPAT_OPTIONS_PREVIOUS
+SET lo_compat_privileges = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET lo_compat_privileges;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET lo_compat_privileges = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lo_compat_privileges;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / DEVELOPER_OPTIONS
+SET allow_system_table_mods = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET allow_system_table_mods;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET allow_system_table_mods = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET allow_system_table_mods;  -- fail, regress_replication_admin has insufficient privileges
+SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, regress_replication_admin has insufficient privileges
+RESET backtrace_functions;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET backtrace_functions;  -- fail, regress_replication_admin has insufficient privileges
+SET debug_discard_caches = 2;  -- fail, regress_replication_admin has insufficient privileges
+RESET debug_discard_caches;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET debug_discard_caches = 2;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET debug_discard_caches;  -- fail, regress_replication_admin has insufficient privileges
+SET ignore_checksum_failure = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET ignore_checksum_failure;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET ignore_checksum_failure = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_checksum_failure;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_dump_bitcode = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET jit_dump_bitcode;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET jit_dump_bitcode = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_dump_bitcode;  -- fail, regress_replication_admin has insufficient privileges
+SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, regress_replication_admin has insufficient privileges
+RESET wal_consistency_checking;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_consistency_checking;  -- fail, regress_replication_admin has insufficient privileges
+SET zero_damaged_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET zero_damaged_pages;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET zero_damaged_pages = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET zero_damaged_pages;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / LOCK_MANAGEMENT
+SET deadlock_timeout = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+RESET deadlock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET deadlock_timeout = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET deadlock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / LOGGING_WHAT
+SET log_duration = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_duration;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_duration = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_duration;  -- fail, regress_replication_admin has insufficient privileges
+SET log_error_verbosity = 'default';  -- fail, regress_replication_admin has insufficient privileges
+RESET log_error_verbosity;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_error_verbosity = 'default';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_error_verbosity;  -- fail, regress_replication_admin has insufficient privileges
+SET log_lock_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_lock_waits;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_lock_waits = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_lock_waits;  -- fail, regress_replication_admin has insufficient privileges
+SET log_parameter_max_length = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_parameter_max_length;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_parameter_max_length = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_parameter_max_length;  -- fail, regress_replication_admin has insufficient privileges
+SET log_replication_commands = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_replication_commands;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_replication_commands = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_replication_commands;  -- fail, regress_replication_admin has insufficient privileges
+SET log_statement = 'none';  -- fail, regress_replication_admin has insufficient privileges
+RESET log_statement;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_statement = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement;  -- fail, regress_replication_admin has insufficient privileges
+SET log_temp_files = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_temp_files;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_temp_files = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_temp_files;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / LOGGING_WHEN
+SET log_min_duration_sample = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_min_duration_sample;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_min_duration_sample = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_duration_sample;  -- fail, regress_replication_admin has insufficient privileges
+SET log_min_duration_statement = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_min_duration_statement;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_min_duration_statement = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_duration_statement;  -- fail, regress_replication_admin has insufficient privileges
+SET log_min_error_statement = 'error';  -- fail, regress_replication_admin has insufficient privileges
+RESET log_min_error_statement;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_min_error_statement = 'error';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_error_statement;  -- fail, regress_replication_admin has insufficient privileges
+SET log_min_messages = 'warning';  -- fail, regress_replication_admin has insufficient privileges
+RESET log_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_min_messages = 'warning';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+SET log_statement_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_statement_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_statement_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+SET log_transaction_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_transaction_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_transaction_sample_rate = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_transaction_sample_rate;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / PROCESS_TITLE
+SET update_process_title = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET update_process_title;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET update_process_title = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET update_process_title;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / RESOURCES_DISK
+SET temp_file_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET temp_file_limit;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET temp_file_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET temp_file_limit;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / RESOURCES_MEM
+SET max_stack_depth = 3890;  -- fail, regress_replication_admin has insufficient privileges
+RESET max_stack_depth;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET max_stack_depth = 3890;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_stack_depth;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / STATS_COLLECTOR
+SET track_activities = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET track_activities;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET track_activities = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_activities;  -- fail, regress_replication_admin has insufficient privileges
+SET track_counts = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET track_counts;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET track_counts = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_counts;  -- fail, regress_replication_admin has insufficient privileges
+SET track_functions = 'none';  -- fail, regress_replication_admin has insufficient privileges
+RESET track_functions;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET track_functions = 'none';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_functions;  -- fail, regress_replication_admin has insufficient privileges
+SET track_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET track_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET track_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+SET track_wal_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET track_wal_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET track_wal_io_timing = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET track_wal_io_timing;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / STATS_MONITORING
+SET log_executor_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_executor_stats;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_executor_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_executor_stats;  -- fail, regress_replication_admin has insufficient privileges
+SET log_parser_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_parser_stats;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_parser_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_parser_stats;  -- fail, regress_replication_admin has insufficient privileges
+SET log_planner_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_planner_stats;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_planner_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_planner_stats;  -- fail, regress_replication_admin has insufficient privileges
+SET log_statement_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET log_statement_stats;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_statement_stats = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement_stats;  -- fail, regress_replication_admin has insufficient privileges
+SET compute_query_id = 'auto';  -- fail, regress_replication_admin has insufficient privileges
+RESET compute_query_id;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET compute_query_id = 'auto';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET compute_query_id;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SUSET / WAL_SETTINGS
+SET commit_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+RESET commit_delay;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET commit_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET commit_delay;  -- fail, regress_replication_admin has insufficient privileges
+SET wal_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+RESET wal_compression;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_compression;  -- fail, regress_replication_admin has insufficient privileges
+SET wal_init_zero = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET wal_init_zero;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_init_zero = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_init_zero;  -- fail, regress_replication_admin has insufficient privileges
+SET wal_recycle = OFF;  -- fail, regress_replication_admin has insufficient privileges
+RESET wal_recycle;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET wal_recycle = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_recycle;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SU_BACKEND / DEVELOPER_OPTIONS
+ALTER SYSTEM SET jit_debugging_support = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_debugging_support;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET jit_profiling_support = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_profiling_support;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_SU_BACKEND / LOGGING_WHAT
+ALTER SYSTEM SET log_connections = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_connections;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM SET log_disconnections = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_disconnections;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_LOCALE
+SET DateStyle = 'ISO, MDY';  -- ok
+RESET DateStyle;  -- ok
+ALTER SYSTEM SET DateStyle = 'ISO, MDY';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET DateStyle;  -- fail, regress_replication_admin has insufficient privileges
+SET IntervalStyle = 'postgres';  -- ok
+RESET IntervalStyle;  -- ok
+ALTER SYSTEM SET IntervalStyle = 'postgres';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET IntervalStyle;  -- fail, regress_replication_admin has insufficient privileges
+SET TimeZone = 'Europe/Helsinki';  -- ok
+RESET TimeZone;  -- ok
+ALTER SYSTEM SET TimeZone = 'Europe/Helsinki';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET TimeZone;  -- fail, regress_replication_admin has insufficient privileges
+SET client_encoding = 'UTF8';  -- ok
+RESET client_encoding;  -- ok
+ALTER SYSTEM SET client_encoding = 'UTF8';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET client_encoding;  -- fail, regress_replication_admin has insufficient privileges
+SET default_text_search_config = 'pg_catalog.english';  -- ok
+RESET default_text_search_config;  -- ok
+ALTER SYSTEM SET default_text_search_config = 'pg_catalog.english';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_text_search_config;  -- fail, regress_replication_admin has insufficient privileges
+SET extra_float_digits = -6;  -- ok
+RESET extra_float_digits;  -- ok
+ALTER SYSTEM SET extra_float_digits = -6;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET extra_float_digits;  -- fail, regress_replication_admin has insufficient privileges
+SET lc_monetary = 'en_US.UTF-8';  -- ok
+RESET lc_monetary;  -- ok
+ALTER SYSTEM SET lc_monetary = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lc_monetary;  -- fail, regress_replication_admin has insufficient privileges
+SET lc_numeric = 'en_US.UTF-8';  -- ok
+RESET lc_numeric;  -- ok
+ALTER SYSTEM SET lc_numeric = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lc_numeric;  -- fail, regress_replication_admin has insufficient privileges
+SET lc_time = 'en_US.UTF-8';  -- ok
+RESET lc_time;  -- ok
+ALTER SYSTEM SET lc_time = 'en_US.UTF-8';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lc_time;  -- fail, regress_replication_admin has insufficient privileges
+SET timezone_abbreviations = 'Default';  -- ok
+RESET timezone_abbreviations;  -- ok
+ALTER SYSTEM SET timezone_abbreviations = 'Default';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET timezone_abbreviations;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_OTHER
+SET gin_fuzzy_search_limit = 50;  -- ok
+RESET gin_fuzzy_search_limit;  -- ok
+ALTER SYSTEM SET gin_fuzzy_search_limit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET gin_fuzzy_search_limit;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_PRELOAD
+SET local_preload_libraries = 'gssapi_krb5';  -- ok
+RESET local_preload_libraries;  -- ok
+ALTER SYSTEM SET local_preload_libraries = 'gssapi_krb5';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET local_preload_libraries;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_STATEMENT
+SET bytea_output = 'hex';  -- ok
+RESET bytea_output;  -- ok
+ALTER SYSTEM SET bytea_output = 'hex';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET bytea_output;  -- fail, regress_replication_admin has insufficient privileges
+SET check_function_bodies = OFF;  -- ok
+RESET check_function_bodies;  -- ok
+ALTER SYSTEM SET check_function_bodies = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET check_function_bodies;  -- fail, regress_replication_admin has insufficient privileges
+SET client_min_messages = 'notice';  -- ok
+RESET client_min_messages;  -- ok
+ALTER SYSTEM SET client_min_messages = 'notice';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET client_min_messages;  -- fail, regress_replication_admin has insufficient privileges
+SET default_table_access_method = 'heap';  -- ok
+RESET default_table_access_method;  -- ok
+ALTER SYSTEM SET default_table_access_method = 'heap';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_table_access_method;  -- fail, regress_replication_admin has insufficient privileges
+SET default_toast_compression = 'pglz';  -- ok
+RESET default_toast_compression;  -- ok
+ALTER SYSTEM SET default_toast_compression = 'pglz';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_toast_compression;  -- fail, regress_replication_admin has insufficient privileges
+SET default_transaction_deferrable = OFF;  -- ok
+RESET default_transaction_deferrable;  -- ok
+ALTER SYSTEM SET default_transaction_deferrable = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_deferrable;  -- fail, regress_replication_admin has insufficient privileges
+SET default_transaction_isolation = 'read committed';  -- ok
+RESET default_transaction_isolation;  -- ok
+ALTER SYSTEM SET default_transaction_isolation = 'read committed';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_isolation;  -- fail, regress_replication_admin has insufficient privileges
+SET default_transaction_read_only = OFF;  -- ok
+RESET default_transaction_read_only;  -- ok
+ALTER SYSTEM SET default_transaction_read_only = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_read_only;  -- fail, regress_replication_admin has insufficient privileges
+SET gin_pending_list_limit = 1073741855;  -- ok
+RESET gin_pending_list_limit;  -- ok
+ALTER SYSTEM SET gin_pending_list_limit = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET gin_pending_list_limit;  -- fail, regress_replication_admin has insufficient privileges
+SET idle_in_transaction_session_timeout = 50;  -- ok
+RESET idle_in_transaction_session_timeout;  -- ok
+ALTER SYSTEM SET idle_in_transaction_session_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET idle_in_transaction_session_timeout;  -- fail, regress_replication_admin has insufficient privileges
+SET idle_session_timeout = 50;  -- ok
+RESET idle_session_timeout;  -- ok
+ALTER SYSTEM SET idle_session_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET idle_session_timeout;  -- fail, regress_replication_admin has insufficient privileges
+SET lock_timeout = 50;  -- ok
+RESET lock_timeout;  -- ok
+ALTER SYSTEM SET lock_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET lock_timeout;  -- fail, regress_replication_admin has insufficient privileges
+SET row_security = OFF;  -- ok
+RESET row_security;  -- ok
+ALTER SYSTEM SET row_security = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET row_security;  -- fail, regress_replication_admin has insufficient privileges
+SET search_path = '"$user", public';  -- ok
+RESET search_path;  -- ok
+ALTER SYSTEM SET search_path = '"$user", public';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET search_path;  -- fail, regress_replication_admin has insufficient privileges
+SET statement_timeout = 5250;  -- ok
+RESET statement_timeout;  -- ok
+ALTER SYSTEM SET statement_timeout = 5250;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET statement_timeout;  -- fail, regress_replication_admin has insufficient privileges
+SET transaction_deferrable = OFF;  -- ok
+RESET transaction_deferrable;  -- ok
+SET transaction_read_only = OFF;  -- ok
+RESET transaction_read_only;  -- ok
+SET vacuum_failsafe_age = 50;  -- ok
+RESET vacuum_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_failsafe_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_failsafe_age;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_freeze_min_age = 50;  -- ok
+RESET vacuum_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_min_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_freeze_min_age;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_freeze_table_age = 50;  -- ok
+RESET vacuum_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_table_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_freeze_table_age;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_multixact_failsafe_age = 50;  -- ok
+RESET vacuum_multixact_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_failsafe_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_failsafe_age;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_multixact_freeze_min_age = 50;  -- ok
+RESET vacuum_multixact_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_min_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_freeze_min_age;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_multixact_freeze_table_age = 50;  -- ok
+RESET vacuum_multixact_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_table_age = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_freeze_table_age;  -- fail, regress_replication_admin has insufficient privileges
+SET xmlbinary = 'base64';  -- ok
+RESET xmlbinary;  -- ok
+ALTER SYSTEM SET xmlbinary = 'base64';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET xmlbinary;  -- fail, regress_replication_admin has insufficient privileges
+SET xmloption = 'content';  -- ok
+RESET xmloption;  -- ok
+ALTER SYSTEM SET xmloption = 'content';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET xmloption;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / COMPAT_OPTIONS_PREVIOUS
+SET escape_string_warning = OFF;  -- ok
+RESET escape_string_warning;  -- ok
+ALTER SYSTEM SET escape_string_warning = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET escape_string_warning;  -- fail, regress_replication_admin has insufficient privileges
+SET array_nulls = OFF;  -- ok
+RESET array_nulls;  -- ok
+ALTER SYSTEM SET array_nulls = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET array_nulls;  -- fail, regress_replication_admin has insufficient privileges
+SET quote_all_identifiers = OFF;  -- ok
+RESET quote_all_identifiers;  -- ok
+ALTER SYSTEM SET quote_all_identifiers = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET quote_all_identifiers;  -- fail, regress_replication_admin has insufficient privileges
+SET standard_conforming_strings = OFF;  -- ok
+RESET standard_conforming_strings;  -- ok
+ALTER SYSTEM SET standard_conforming_strings = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET standard_conforming_strings;  -- fail, regress_replication_admin has insufficient privileges
+SET synchronize_seqscans = OFF;  -- ok
+RESET synchronize_seqscans;  -- ok
+ALTER SYSTEM SET synchronize_seqscans = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET synchronize_seqscans;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_AUTH
+SET password_encryption = 'scram-sha-256';  -- ok
+RESET password_encryption;  -- ok
+ALTER SYSTEM SET password_encryption = 'scram-sha-256';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET password_encryption;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_SETTINGS
+SET client_connection_check_interval = 0;  -- ok
+RESET client_connection_check_interval;  -- ok
+ALTER SYSTEM SET client_connection_check_interval = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET client_connection_check_interval;  -- fail, regress_replication_admin has insufficient privileges
+SET tcp_keepalives_count = 50;  -- ok
+RESET tcp_keepalives_count;  -- ok
+ALTER SYSTEM SET tcp_keepalives_count = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_count;  -- fail, regress_replication_admin has insufficient privileges
+SET tcp_keepalives_idle = 50;  -- ok
+RESET tcp_keepalives_idle;  -- ok
+ALTER SYSTEM SET tcp_keepalives_idle = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_idle;  -- fail, regress_replication_admin has insufficient privileges
+SET tcp_keepalives_interval = 50;  -- ok
+RESET tcp_keepalives_interval;  -- ok
+ALTER SYSTEM SET tcp_keepalives_interval = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_interval;  -- fail, regress_replication_admin has insufficient privileges
+SET tcp_user_timeout = 50;  -- ok
+RESET tcp_user_timeout;  -- ok
+ALTER SYSTEM SET tcp_user_timeout = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_user_timeout;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_SSL
+SET ssl_renegotiation_limit = 0;  -- ok
+RESET ssl_renegotiation_limit;  -- ok
+-- PGC_USERSET / DEVELOPER_OPTIONS
+SET force_parallel_mode = 'off';  -- ok
+RESET force_parallel_mode;  -- ok
+ALTER SYSTEM SET force_parallel_mode = 'off';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET force_parallel_mode;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_expressions = OFF;  -- ok
+RESET jit_expressions;  -- ok
+ALTER SYSTEM SET jit_expressions = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_expressions;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_tuple_deforming = OFF;  -- ok
+RESET jit_tuple_deforming;  -- ok
+ALTER SYSTEM SET jit_tuple_deforming = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_tuple_deforming;  -- fail, regress_replication_admin has insufficient privileges
+SET trace_notify = OFF;  -- ok
+RESET trace_notify;  -- ok
+ALTER SYSTEM SET trace_notify = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET trace_notify;  -- fail, regress_replication_admin has insufficient privileges
+SET trace_sort = OFF;  -- ok
+RESET trace_sort;  -- ok
+ALTER SYSTEM SET trace_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET trace_sort;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / ERROR_HANDLING_OPTIONS
+SET exit_on_error = OFF;  -- ok
+RESET exit_on_error;  -- ok
+ALTER SYSTEM SET exit_on_error = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET exit_on_error;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / LOGGING_WHAT
+SET application_name = 'psql';  -- ok
+RESET application_name;  -- ok
+ALTER SYSTEM SET application_name = 'psql';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET application_name;  -- fail, regress_replication_admin has insufficient privileges
+SET debug_pretty_print = OFF;  -- ok
+RESET debug_pretty_print;  -- ok
+ALTER SYSTEM SET debug_pretty_print = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET debug_pretty_print;  -- fail, regress_replication_admin has insufficient privileges
+SET debug_print_parse = OFF;  -- ok
+RESET debug_print_parse;  -- ok
+ALTER SYSTEM SET debug_print_parse = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_parse;  -- fail, regress_replication_admin has insufficient privileges
+SET debug_print_plan = OFF;  -- ok
+RESET debug_print_plan;  -- ok
+ALTER SYSTEM SET debug_print_plan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_plan;  -- fail, regress_replication_admin has insufficient privileges
+SET debug_print_rewritten = OFF;  -- ok
+RESET debug_print_rewritten;  -- ok
+ALTER SYSTEM SET debug_print_rewritten = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_rewritten;  -- fail, regress_replication_admin has insufficient privileges
+SET log_parameter_max_length_on_error = 50;  -- ok
+RESET log_parameter_max_length_on_error;  -- ok
+ALTER SYSTEM SET log_parameter_max_length_on_error = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET log_parameter_max_length_on_error;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_COST
+SET cpu_index_tuple_cost = 50;  -- ok
+RESET cpu_index_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_index_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_index_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET cpu_operator_cost = 50;  -- ok
+RESET cpu_operator_cost;  -- ok
+ALTER SYSTEM SET cpu_operator_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_operator_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET cpu_tuple_cost = 50;  -- ok
+RESET cpu_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET effective_cache_size = 1073741824;  -- ok
+RESET effective_cache_size;  -- ok
+ALTER SYSTEM SET effective_cache_size = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET effective_cache_size;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_above_cost = 50;  -- ok
+RESET jit_above_cost;  -- ok
+ALTER SYSTEM SET jit_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_inline_above_cost = 50;  -- ok
+RESET jit_inline_above_cost;  -- ok
+ALTER SYSTEM SET jit_inline_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_inline_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET jit_optimize_above_cost = 50;  -- ok
+RESET jit_optimize_above_cost;  -- ok
+ALTER SYSTEM SET jit_optimize_above_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit_optimize_above_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET min_parallel_index_scan_size = 50;  -- ok
+RESET min_parallel_index_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_index_scan_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET min_parallel_index_scan_size;  -- fail, regress_replication_admin has insufficient privileges
+SET min_parallel_table_scan_size = 50;  -- ok
+RESET min_parallel_table_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_table_scan_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET min_parallel_table_scan_size;  -- fail, regress_replication_admin has insufficient privileges
+SET parallel_setup_cost = 50;  -- ok
+RESET parallel_setup_cost;  -- ok
+ALTER SYSTEM SET parallel_setup_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_setup_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET parallel_tuple_cost = 50;  -- ok
+RESET parallel_tuple_cost;  -- ok
+ALTER SYSTEM SET parallel_tuple_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_tuple_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET random_page_cost = 50;  -- ok
+RESET random_page_cost;  -- ok
+ALTER SYSTEM SET random_page_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET random_page_cost;  -- fail, regress_replication_admin has insufficient privileges
+SET seq_page_cost = 50;  -- ok
+RESET seq_page_cost;  -- ok
+ALTER SYSTEM SET seq_page_cost = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET seq_page_cost;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_GEQO
+SET geqo = OFF;  -- ok
+RESET geqo;  -- ok
+ALTER SYSTEM SET geqo = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_effort = 5;  -- ok
+RESET geqo_effort;  -- ok
+ALTER SYSTEM SET geqo_effort = 5;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_effort;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_generations = 50;  -- ok
+RESET geqo_generations;  -- ok
+ALTER SYSTEM SET geqo_generations = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_generations;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_pool_size = 50;  -- ok
+RESET geqo_pool_size;  -- ok
+ALTER SYSTEM SET geqo_pool_size = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_pool_size;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_seed = 0;  -- ok
+RESET geqo_seed;  -- ok
+ALTER SYSTEM SET geqo_seed = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_seed;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_selection_bias = 2;  -- ok
+RESET geqo_selection_bias;  -- ok
+ALTER SYSTEM SET geqo_selection_bias = 2;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_selection_bias;  -- fail, regress_replication_admin has insufficient privileges
+SET geqo_threshold = 1073741824;  -- ok
+RESET geqo_threshold;  -- ok
+ALTER SYSTEM SET geqo_threshold = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_threshold;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_METHOD
+SET enable_async_append = OFF;  -- ok
+RESET enable_async_append;  -- ok
+ALTER SYSTEM SET enable_async_append = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_async_append;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_bitmapscan = OFF;  -- ok
+RESET enable_bitmapscan;  -- ok
+ALTER SYSTEM SET enable_bitmapscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_bitmapscan;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_gathermerge = OFF;  -- ok
+RESET enable_gathermerge;  -- ok
+ALTER SYSTEM SET enable_gathermerge = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_gathermerge;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_hashagg = OFF;  -- ok
+RESET enable_hashagg;  -- ok
+ALTER SYSTEM SET enable_hashagg = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_hashagg;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_hashjoin = OFF;  -- ok
+RESET enable_hashjoin;  -- ok
+ALTER SYSTEM SET enable_hashjoin = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_hashjoin;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_incremental_sort = OFF;  -- ok
+RESET enable_incremental_sort;  -- ok
+ALTER SYSTEM SET enable_incremental_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_incremental_sort;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_indexonlyscan = OFF;  -- ok
+RESET enable_indexonlyscan;  -- ok
+ALTER SYSTEM SET enable_indexonlyscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_indexonlyscan;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_indexscan = OFF;  -- ok
+RESET enable_indexscan;  -- ok
+ALTER SYSTEM SET enable_indexscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_indexscan;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_material = OFF;  -- ok
+RESET enable_material;  -- ok
+ALTER SYSTEM SET enable_material = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_material;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_memoize = OFF;  -- ok
+RESET enable_memoize;  -- ok
+ALTER SYSTEM SET enable_memoize = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_memoize;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_mergejoin = OFF;  -- ok
+RESET enable_mergejoin;  -- ok
+ALTER SYSTEM SET enable_mergejoin = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_mergejoin;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_nestloop = OFF;  -- ok
+RESET enable_nestloop;  -- ok
+ALTER SYSTEM SET enable_nestloop = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_nestloop;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_parallel_append = OFF;  -- ok
+RESET enable_parallel_append;  -- ok
+ALTER SYSTEM SET enable_parallel_append = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_parallel_append;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_parallel_hash = OFF;  -- ok
+RESET enable_parallel_hash;  -- ok
+ALTER SYSTEM SET enable_parallel_hash = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_parallel_hash;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_partition_pruning = OFF;  -- ok
+RESET enable_partition_pruning;  -- ok
+ALTER SYSTEM SET enable_partition_pruning = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partition_pruning;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_partitionwise_aggregate = OFF;  -- ok
+RESET enable_partitionwise_aggregate;  -- ok
+ALTER SYSTEM SET enable_partitionwise_aggregate = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partitionwise_aggregate;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_partitionwise_join = OFF;  -- ok
+RESET enable_partitionwise_join;  -- ok
+ALTER SYSTEM SET enable_partitionwise_join = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partitionwise_join;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_seqscan = OFF;  -- ok
+RESET enable_seqscan;  -- ok
+ALTER SYSTEM SET enable_seqscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_seqscan;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_sort = OFF;  -- ok
+RESET enable_sort;  -- ok
+ALTER SYSTEM SET enable_sort = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_sort;  -- fail, regress_replication_admin has insufficient privileges
+SET enable_tidscan = OFF;  -- ok
+RESET enable_tidscan;  -- ok
+ALTER SYSTEM SET enable_tidscan = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET enable_tidscan;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_OTHER
+SET constraint_exclusion = 'partition';  -- ok
+RESET constraint_exclusion;  -- ok
+ALTER SYSTEM SET constraint_exclusion = 'partition';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET constraint_exclusion;  -- fail, regress_replication_admin has insufficient privileges
+SET cursor_tuple_fraction = 0;  -- ok
+RESET cursor_tuple_fraction;  -- ok
+ALTER SYSTEM SET cursor_tuple_fraction = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET cursor_tuple_fraction;  -- fail, regress_replication_admin has insufficient privileges
+SET default_statistics_target = 5000;  -- ok
+RESET default_statistics_target;  -- ok
+ALTER SYSTEM SET default_statistics_target = 5000;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET default_statistics_target;  -- fail, regress_replication_admin has insufficient privileges
+SET from_collapse_limit = 1073741824;  -- ok
+RESET from_collapse_limit;  -- ok
+ALTER SYSTEM SET from_collapse_limit = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET from_collapse_limit;  -- fail, regress_replication_admin has insufficient privileges
+SET jit = OFF;  -- ok
+RESET jit;  -- ok
+ALTER SYSTEM SET jit = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET jit;  -- fail, regress_replication_admin has insufficient privileges
+SET join_collapse_limit = 1073741824;  -- ok
+RESET join_collapse_limit;  -- ok
+ALTER SYSTEM SET join_collapse_limit = 1073741824;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET join_collapse_limit;  -- fail, regress_replication_admin has insufficient privileges
+SET plan_cache_mode = 'force_generic_plan';  -- ok
+RESET plan_cache_mode;  -- ok
+ALTER SYSTEM SET plan_cache_mode = 'force_generic_plan';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET plan_cache_mode;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / REPLICATION_SENDING
+SET wal_sender_timeout = 50;  -- ok
+RESET wal_sender_timeout;  -- ok
+ALTER SYSTEM SET wal_sender_timeout = 50;  -- ok
+ALTER SYSTEM RESET wal_sender_timeout;  -- ok
+-- PGC_USERSET / RESOURCES_ASYNCHRONOUS
+SET backend_flush_after = 128;  -- ok
+RESET backend_flush_after;  -- ok
+ALTER SYSTEM SET backend_flush_after = 128;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET backend_flush_after;  -- fail, regress_replication_admin has insufficient privileges
+SET effective_io_concurrency = 0;  -- ok
+RESET effective_io_concurrency;  -- ok
+ALTER SYSTEM SET effective_io_concurrency = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET effective_io_concurrency;  -- fail, regress_replication_admin has insufficient privileges
+SET maintenance_io_concurrency = 0;  -- ok
+RESET maintenance_io_concurrency;  -- ok
+ALTER SYSTEM SET maintenance_io_concurrency = 0;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET maintenance_io_concurrency;  -- fail, regress_replication_admin has insufficient privileges
+SET max_parallel_maintenance_workers = 50;  -- ok
+RESET max_parallel_maintenance_workers;  -- ok
+ALTER SYSTEM SET max_parallel_maintenance_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_maintenance_workers;  -- fail, regress_replication_admin has insufficient privileges
+SET max_parallel_workers = 50;  -- ok
+RESET max_parallel_workers;  -- ok
+ALTER SYSTEM SET max_parallel_workers = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_workers;  -- fail, regress_replication_admin has insufficient privileges
+SET max_parallel_workers_per_gather = 50;  -- ok
+RESET max_parallel_workers_per_gather;  -- ok
+ALTER SYSTEM SET max_parallel_workers_per_gather = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_workers_per_gather;  -- fail, regress_replication_admin has insufficient privileges
+SET parallel_leader_participation = OFF;  -- ok
+RESET parallel_leader_participation;  -- ok
+ALTER SYSTEM SET parallel_leader_participation = OFF;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_leader_participation;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / RESOURCES_MEM
+SET hash_mem_multiplier = 500;  -- ok
+RESET hash_mem_multiplier;  -- ok
+ALTER SYSTEM SET hash_mem_multiplier = 500;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET hash_mem_multiplier;  -- fail, regress_replication_admin has insufficient privileges
+SET logical_decoding_work_mem = 1073741855;  -- ok
+RESET logical_decoding_work_mem;  -- ok
+ALTER SYSTEM SET logical_decoding_work_mem = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET logical_decoding_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+SET maintenance_work_mem = 1073742335;  -- ok
+RESET maintenance_work_mem;  -- ok
+ALTER SYSTEM SET maintenance_work_mem = 1073742335;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET maintenance_work_mem;  -- fail, regress_replication_admin has insufficient privileges
+SET temp_buffers = 536870961;  -- ok
+RESET temp_buffers;  -- ok
+ALTER SYSTEM SET temp_buffers = 536870961;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET temp_buffers;  -- fail, regress_replication_admin has insufficient privileges
+SET work_mem = 1073741855;  -- ok
+RESET work_mem;  -- ok
+ALTER SYSTEM SET work_mem = 1073741855;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET work_mem;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / RESOURCES_VACUUM_DELAY
+SET vacuum_cost_delay = 50;  -- ok
+RESET vacuum_cost_delay;  -- ok
+ALTER SYSTEM SET vacuum_cost_delay = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_delay;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_cost_limit = 5000;  -- ok
+RESET vacuum_cost_limit;  -- ok
+ALTER SYSTEM SET vacuum_cost_limit = 5000;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_limit;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_cost_page_dirty = 50;  -- ok
+RESET vacuum_cost_page_dirty;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_dirty = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_dirty;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_cost_page_hit = 50;  -- ok
+RESET vacuum_cost_page_hit;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_hit = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_hit;  -- fail, regress_replication_admin has insufficient privileges
+SET vacuum_cost_page_miss = 50;  -- ok
+RESET vacuum_cost_page_miss;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_miss = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_miss;  -- fail, regress_replication_admin has insufficient privileges
+-- PGC_USERSET / UNGROUPED
+SET seed = 0;  -- ok
+RESET seed;  -- ok
+-- PGC_USERSET / WAL_SETTINGS
+SET commit_siblings = 50;  -- ok
+RESET commit_siblings;  -- ok
+ALTER SYSTEM SET commit_siblings = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET commit_siblings;  -- fail, regress_replication_admin has insufficient privileges
+SET synchronous_commit = 'remote_write';  -- ok
+RESET synchronous_commit;  -- ok
+ALTER SYSTEM SET synchronous_commit = 'remote_write';  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET synchronous_commit;  -- fail, regress_replication_admin has insufficient privileges
+SET wal_skip_threshold = 50;  -- ok
+RESET wal_skip_threshold;  -- ok
+ALTER SYSTEM SET wal_skip_threshold = 50;  -- fail, regress_replication_admin has insufficient privileges
+ALTER SYSTEM RESET wal_skip_threshold;  -- fail, regress_replication_admin has insufficient privileges
+RESET statement_timeout;
+RESET SESSION AUTHORIZATION;
+DROP ROLE regress_replication_admin;
-- 
2.21.1 (Apple Git-122.3)

